@@ -1,11 +1,10 @@
 /* -*- Mode: C; tab-width: 4 -*- */
 /*-
  * ant --- Chris Langton's generalized turing machine ants (also known
- *         as Greg Turk's turmites) whose tape is the screen
- */
+ *         as Greg Turk's turmites) whose tape is the screen */
 
 #if !defined( lint ) && !defined( SABER )
-static const char sccsid[] = "@(#)ant.c	5.13 2004/06/23 xlockmore";
+static const char sccsid[] = "@(#)ant.c	5.24 2007/01/18 xlockmore";
 
 #endif
 
@@ -25,6 +24,7 @@ static const char sccsid[] = "@(#)ant.c	5.13 2004/06/23 xlockmore";
  * other special, indirect and consequential damages.
  *
  * Revision History:
+ * 18-Jan-2007: Added vertical option.
  * 01-Nov-2000: Allocation checks
  * 10-May-1997: Compatible with xscreensaver
  * 16-Apr-1997: -neighbors 3 and 8 added
@@ -76,6 +76,10 @@ static const char sccsid[] = "@(#)ant.c	5.13 2004/06/23 xlockmore";
 
 #ifdef MODE_ant
 
+#define DEF_LABEL "True"
+#define FONT_HEIGHT 19
+#define FONT_WIDTH 15
+
 /*-
  * neighbors of 0 randomizes it for 3, 4, 6, 8, 12 (last 2 are less likely)
  */
@@ -85,15 +89,20 @@ static const char sccsid[] = "@(#)ant.c	5.13 2004/06/23 xlockmore";
 #define DEF_TRUCHET  "False"
 #define DEF_EYES  "False"
 #define DEF_SHARPTURN  "False"
+#define DEF_VERTICAL "False"
 
+static Bool label;
 static int  neighbors;
 static char *rule;
 static Bool truchet;
 static Bool eyes;
 static Bool sharpturn;
+static Bool vertical;
 
 static XrmOptionDescRec opts[] =
 {
+	{(char *) "-label", (char *) ".ant.label", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+label", (char *) ".ant.label", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-neighbors", (char *) ".ant.neighbors", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-rule", (char *) ".ant.rule", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-truchet", (char *) ".ant.truchet", XrmoptionNoArg, (caddr_t) "on"},
@@ -101,23 +110,29 @@ static XrmOptionDescRec opts[] =
 	{(char *) "-eyes", (char *) ".ant.eyes", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+eyes", (char *) ".ant.eyes", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-sharpturn", (char *) ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "on"},
-	{(char *) "+sharpturn", (char *) ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "+sharpturn", (char *) ".ant.sharpturn", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-vertical", (char *) ".ant.vertical", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+vertical", (char *) ".ant.vertical", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-	{(caddr_t *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
-	{(caddr_t *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
-	{(caddr_t *) & truchet, (char *) "truchet", (char *) "Truchet", (char *) DEF_TRUCHET, t_Bool},
-	{(caddr_t *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool},
-   {(caddr_t *) & sharpturn, (char *) "sharpturn", (char *) "SharpTurn", (char *) DEF_SHARPTURN, t_Bool}
+	{(void *) & label, (char *) "label", (char *) "Label", (char *) DEF_LABEL, t_Bool},
+	{(void *) & neighbors, (char *) "neighbors", (char *) "Neighbors", (char *) DEF_NEIGHBORS, t_Int},
+	{(void *) & rule, (char *) "rule", (char *) "Rule", (char *) DEF_RULE, t_String},
+	{(void *) & truchet, (char *) "truchet", (char *) "Truchet", (char *) DEF_TRUCHET, t_Bool},
+	{(void *) & eyes, (char *) "eyes", (char *) "Eyes", (char *) DEF_EYES, t_Bool},
+	{(void *) & sharpturn, (char *) "sharpturn", (char *) "SharpTurn", (char *) DEF_SHARPTURN, t_Bool},
+	{(void *) & vertical, (char *) "vertical", (char *) "Vertical", (char *) DEF_VERTICAL, t_Bool}
 };
 static OptionStruct desc[] =
 {
+	{(char *) "-/+label", (char *) "turn on/off rule labeling"},
 	{(char *) "-neighbors num", (char *) "squares 4 or 8, hexagons 6, triangles 3 or 12"},
 	{(char *) "-rule string", (char *) "binary string for Turk's Ant"},
 	{(char *) "-/+truchet", (char *) "turn on/off Truchet lines"},
 	{(char *) "-/+eyes", (char *) "turn on/off eyes"},
-	{(char *) "-/+sharpturn", (char *) "turn on/off sharp turns (6, 8 or 12 neighbors only)"}
+	{(char *) "-/+sharpturn", (char *) "turn on/off sharp turns (6, 8 or 12 neighbors only)"},
+	{(char *) "-/+vertical", (char *) "change orientation for hexagons and triangles"}
 };
 
 ModeSpecOpt ant_opts =
@@ -160,7 +175,7 @@ typedef struct {
 } antstruct;
 
 typedef struct {
-	Bool        painted;
+	Bool        painted, vertical;
 	int         neighbors;
 	int         generation;
 	int         xs, ys;
@@ -182,6 +197,8 @@ typedef struct {
 	unsigned char colors[NUMSTIPPLES - 1];
 	GC          stippledGC;
 	Pixmap      pixmaps[NUMSTIPPLES - 1];
+	int         labelOffsetX, labelOffsetY;
+	char        ruleString[50];
 	union {
 		XPoint      hexagon[7];		/* Need more than 6 for truchet */
 		XPoint      triangle[2][4];	/* Need more than 3 for truchet */
@@ -261,207 +278,207 @@ static unsigned char tables[][3 * NUMSTIPPLES * STATES + 2] =
 static void
 position_of_neighbor(antfarmstruct * ap, int dir, int *pcol, int *prow)
 {
-	int         col = *pcol, row = *prow;
+	int col = *pcol, row = *prow;
 
 	if (ap->neighbors == 4 || ap->neighbors == 6 || ap->neighbors == 8) {
 		switch (dir) {
-			case 0:
+		case 0:
+			col = (col + 1 == ap->ncols) ? 0 : col + 1;
+			break;
+		case 45:
+			col = (col + 1 == ap->ncols) ? 0 : col + 1;
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 60:
+			if (!(row & 1))
 				col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				break;
-			case 45:
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 90:
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 120:
+			if (row & 1)
+				col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 135:
+			col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (!row) ? ap->nrows - 1 : row - 1;
+			break;
+		case 180:
+			col = (!col) ? ap->ncols - 1 : col - 1;
+			break;
+		case 225:
+			col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 240:
+			if (row & 1)
+				col = (!col) ? ap->ncols - 1 : col - 1;
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 270:
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 300:
+			if (!(row & 1))
 				col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 60:
-				if (!(row & 1))
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 90:
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 120:
-				if (row & 1)
-					col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 135:
-				col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (!row) ? ap->nrows - 1 : row - 1;
-				break;
-			case 180:
-				col = (!col) ? ap->ncols - 1 : col - 1;
-				break;
-			case 225:
-				col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 240:
-				if (row & 1)
-					col = (!col) ? ap->ncols - 1 : col - 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 270:
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 300:
-				if (!(row & 1))
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			case 315:
-				col = (col + 1 == ap->ncols) ? 0 : col + 1;
-				row = (row + 1 == ap->nrows) ? 0 : row + 1;
-				break;
-			default:
-				(void) fprintf(stderr, "wrong direction %d\n", dir);
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		case 315:
+			col = (col + 1 == ap->ncols) ? 0 : col + 1;
+			row = (row + 1 == ap->nrows) ? 0 : row + 1;
+			break;
+		default:
+			(void) fprintf(stderr, "wrong direction %d\n", dir);
 		}
 	} else {		/* TRI */
 		if ((col + row) % 2) {	/* right */
 			switch (dir) {
-				case 0:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					break;
-				case 30:
-				case 40:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 60:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					if (!row)
-						row = ap->nrows - 2;
-					else if (!(row - 1))
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 80:
-				case 90:
-					if (!row)
-						row = ap->nrows - 2;
-					else if (!(row - 1))
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 120:
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 150:
-				case 160:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 180:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					break;
-				case 200:
-				case 210:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 240:
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 270:
-				case 280:
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 300:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 320:
-				case 330:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				default:
-					(void) fprintf(stderr, "wrong direction %d\n", dir);
+			case 0:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				break;
+			case 30:
+			case 40:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 60:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				if (!row)
+					row = ap->nrows - 2;
+				else if (!(row - 1))
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 80:
+			case 90:
+				if (!row)
+					row = ap->nrows - 2;
+				else if (!(row - 1))
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 120:
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 150:
+			case 160:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 180:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				break;
+			case 200:
+			case 210:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 240:
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 270:
+			case 280:
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 300:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 320:
+			case 330:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			default:
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 			}
 		} else {	/* left */
 			switch (dir) {
-				case 0:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					break;
-				case 30:
-				case 40:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 60:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 80:
-				case 90:
-					if (row + 1 == ap->nrows)
-						row = 1;
-					else if (row + 2 == ap->nrows)
-						row = 0;
-					else
-						row = row + 2;
-					break;
-				case 120:
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 150:
-				case 160:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (row + 1 == ap->nrows) ? 0 : row + 1;
-					break;
-				case 180:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					break;
-				case 200:
-				case 210:
-					col = (!col) ? ap->ncols - 1 : col - 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 240:
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				case 270:
-				case 280:
-					if (!row)
-						row = ap->nrows - 2;
-					else if (row == 1)
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 300:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					if (!row)
-						row = ap->nrows - 2;
-					else if (row == 1)
-						row = ap->nrows - 1;
-					else
-						row = row - 2;
-					break;
-				case 320:
-				case 330:
-					col = (col + 1 == ap->ncols) ? 0 : col + 1;
-					row = (!row) ? ap->nrows - 1 : row - 1;
-					break;
-				default:
-					(void) fprintf(stderr, "wrong direction %d\n", dir);
+			case 0:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				break;
+			case 30:
+			case 40:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 60:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 80:
+			case 90:
+				if (row + 1 == ap->nrows)
+					row = 1;
+				else if (row + 2 == ap->nrows)
+					row = 0;
+				else
+					row = row + 2;
+				break;
+			case 120:
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 150:
+			case 160:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (row + 1 == ap->nrows) ? 0 : row + 1;
+				break;
+			case 180:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				break;
+			case 200:
+			case 210:
+				col = (!col) ? ap->ncols - 1 : col - 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 240:
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			case 270:
+			case 280:
+				if (!row)
+					row = ap->nrows - 2;
+				else if (row == 1)
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 300:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				if (!row)
+					row = ap->nrows - 2;
+				else if (row == 1)
+					row = ap->nrows - 1;
+				else
+					row = row - 2;
+				break;
+			case 320:
+			case 330:
+				col = (col + 1 == ap->ncols) ? 0 : col + 1;
+				row = (!row) ? ap->nrows - 1 : row - 1;
+				break;
+			default:
+				(void) fprintf(stderr, "wrong direction %d\n", dir);
 			}
 		}
 	}
@@ -473,38 +490,64 @@ static void
 fillcell(ModeInfo * mi, GC gc, int col, int row)
 {
 	antfarmstruct *ap = &antfarms[MI_SCREEN(mi)];
+	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
 
 	if (ap->neighbors == 6) {
 		int         ccol = 2 * col + !(row & 1), crow = 2 * row;
 
-		ap->shape.hexagon[0].x = ap->xb + ccol * ap->xs;
-		ap->shape.hexagon[0].y = ap->yb + crow * ap->ys;
+		if (ap->vertical) {
+			ap->shape.hexagon[0].x = ap->xb + ccol * ap->xs;
+			ap->shape.hexagon[0].y = ap->yb + crow * ap->ys;
+		} else {
+			ap->shape.hexagon[0].y = ap->xb + ccol * ap->xs;
+			ap->shape.hexagon[0].x = ap->yb + crow * ap->ys;
+		}
 		if (ap->xs == 1 && ap->ys == 1)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XDrawPoint(display, window, gc,
 			ap->shape.hexagon[0].x, ap->shape.hexagon[0].y);
 		else
-			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+			XFillPolygon(display, window, gc,
 			    ap->shape.hexagon, 6, Convex, CoordModePrevious);
 	} else if (ap->neighbors == 4 || ap->neighbors == 8) {
-		XFillRectangle(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
+		XFillRectangle(display, window, gc,
 		ap->xb + ap->xs * col, ap->yb + ap->ys * row,
 	 	ap->xs - (ap->xs > 3), ap->ys - (ap->ys > 3));
 	} else {		/* TRI */
-		int         orient = (col + row) % 2;	/* O left 1 right */
+		int orient = (col + row) % 2;	/* O left 1 right */
+		Bool small = (ap->xs <= 3 || ap->ys <= 3);
 
-		ap->shape.triangle[orient][0].x = ap->xb + col * ap->xs;
-		ap->shape.triangle[orient][0].y = ap->yb + row * ap->ys;
-		if (ap->xs <= 3 || ap->ys <= 3)
-			XDrawPoint(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-			((orient) ? -1 : 1) + ap->shape.triangle[orient][0].x,
-				       ap->shape.triangle[orient][0].y);
-		else {
-			if (orient)
-				ap->shape.triangle[orient][0].x += (ap->xs / 2 - 1);
+		if (ap->vertical) {
+			ap->shape.triangle[orient][0].x = ap->xb + col * ap->xs;
+			ap->shape.triangle[orient][0].y = ap->yb + row * ap->ys;
+			if (small)
+				ap->shape.triangle[orient][0].x +=
+					((orient) ? -1 : 1);
 			else
-				ap->shape.triangle[orient][0].x -= (ap->xs / 2 - 1);
-			XFillPolygon(MI_DISPLAY(mi), MI_WINDOW(mi), gc,
-				     ap->shape.triangle[orient], 3, Convex, CoordModePrevious);
+				ap->shape.triangle[orient][0].x +=
+					(ap->xs / 2  - 1) * ((orient) ? 1 : -1);
+		} else {
+			ap->shape.triangle[orient][0].y = ap->xb + col * ap->xs;
+			ap->shape.triangle[orient][0].x = ap->yb + row * ap->ys;
+			if (small)
+				ap->shape.triangle[orient][0].y +=
+					((orient) ? -1 : 1);
+			else
+				ap->shape.triangle[orient][0].y +=
+					(ap->xs / 2  - 1) * ((orient) ? 1 : -1);
+		}
+		if (small)
+			XDrawPoint(display, window, gc,
+				ap->shape.triangle[orient][0].x,
+				ap->shape.triangle[orient][0].y);
+		else {
+			XFillPolygon(display, window, gc,
+				ap->shape.triangle[orient], 3,
+				Convex, CoordModePrevious);
+			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
+			XDrawLines(display, window, gc,
+				ap->shape.triangle[orient], 4,
+				CoordModePrevious);
 		}
 	}
 }
@@ -526,13 +569,26 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 			hex.y = ap->yb + crow * ap->ys - (int) ((double) ap->ys / 2.0) - 1;
 			for (side = 0; side < 6; side++) {
 				if (side) {
-					hex.x += ap->shape.hexagon[side].x;
-					hex.y += ap->shape.hexagon[side].y;
+					if (ap->vertical) {
+						hex.x += ap->shape.hexagon[side].x;
+						hex.y += ap->shape.hexagon[side].y;
+					} else {
+						hex.y += ap->shape.hexagon[side].x;
+						hex.x += ap->shape.hexagon[side].y;
+					}
 				}
 				if (truchetstate == side % 2)
-					XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-						 hex.x, hex.y, ap->xs, ap->ys,
-						 ((570 - (side * 60) + fudge) % 360) * 64, (120 - 2 * fudge) * 64);
+					if (ap->vertical) {
+					    XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+						hex.x, hex.y, ap->xs, ap->ys,
+						((570 - (side * 60) + fudge) % 360) * 64,
+						(120 - 2 * fudge) * 64);
+					} else {
+					    XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+						hex.y, hex.x, ap->ys, ap->xs,
+						((300 + (side * 60) + fudge) % 360) * 64,
+						(120 - 2 * fudge) * 64);
+					}
 			}
 		} else {
 			/* Very crude approx of Sqrt 3, so it will not cause drawing errors. */
@@ -540,11 +596,21 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 			hex.y = ap->yb + crow * ap->ys - (int) ((double) ap->ys * 1.6 / 2.0) - 1;
 			for (side = 0; side < 6; side++) {
 				if (side) {
-					hex.x += ap->shape.hexagon[side].x;
-					hex.y += ap->shape.hexagon[side].y;
+					if (ap->vertical) {
+						hex.x += ap->shape.hexagon[side].x;
+						hex.y += ap->shape.hexagon[side].y;
+					} else {
+						hex.y += ap->shape.hexagon[side].x;
+						hex.x += ap->shape.hexagon[side].y;
+					}
+				}
+				if (ap->vertical) {
+					hex2.x = hex.x + ap->shape.hexagon[side + 1].x / 2;
+					hex2.y = hex.y + ap->shape.hexagon[side + 1].y / 2 + 1;
+				} else {
+					hex2.y = hex.y + ap->shape.hexagon[side + 1].x / 2;
+					hex2.x = hex.x + ap->shape.hexagon[side + 1].y / 2 + 1;
 				}
-				hex2.x = hex.x + ap->shape.hexagon[side + 1].x / 2;
-				hex2.y = hex.y + ap->shape.hexagon[side + 1].y / 2 + 1;
 				/* Lots of fudging here */
 				if (side == 0) {
 					hex2.x += 1;
@@ -565,10 +631,17 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 				}
 				if (truchetstate == side % 3)
 					/* Crude approx of 120 deg, so it will not cause drawing errors. */
-					XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+					if (ap->vertical) {
+					    XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 						 hex2.x, hex2.y,
 						 (int) ((double) ap->xs * 1.5), (int) ((double) ap->ys * 1.5),
 						 ((555 - (side * 60)) % 360) * 64, 90 * 64);
+					} else {
+					    XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+						 hex2.y, hex2.x,
+						 (int) ((double) ap->ys * 1.5), (int) ((double) ap->xs * 1.5),
+						 ((345 + (side * 60)) % 360) * 64, 90 * 64);
+					}
 			}
 		}
 	} else if (ap->neighbors == 4) {
@@ -611,20 +684,41 @@ truchetcell(ModeInfo * mi, int col, int row, int truchetstate)
 		}
 		for (side = 0; side < 3; side++) {
 			if (side > 0) {
-				tri.x += ap->shape.triangle[orient][side].x;
-				tri.y += ap->shape.triangle[orient][side].y;
+				if (ap->vertical) {
+					tri.x += ap->shape.triangle[orient][side].x;
+					tri.y += ap->shape.triangle[orient][side].y;
+				} else {
+					tri.y += ap->shape.triangle[orient][side].x;
+					tri.x += ap->shape.triangle[orient][side].y;
+				}
 			}
 			if (truchetstate == side) {
-				if (orient)
-					ang = (510 - side * 120) % 360;		/* Right */
-				else
-					ang = (690 - side * 120) % 360;		/* Left */
-				XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
-				  (int) (tri.x - ap->xs * fudge2 / 2),
-          (int) (tri.y - 3 * ap->ys * fudge2 / 4),
-				  (unsigned int) (ap->xs * fudge2),
-          (unsigned int) (3 * ap->ys * fudge2 / 2),
-				  (ang + fudge) * 64, (60 - 2 * fudge) * 64);
+				if (ap->vertical) {
+					if (orient)
+						ang = (510 - side * 120) % 360;		/* Right */
+					else
+						ang = (690 - side * 120) % 360;		/* Left */
+				} else {
+					if (orient)
+						ang = (60 + side * 120) % 360;		/* Right */
+					else
+						ang = (240 + side * 120) % 360;		/* Left */
+				}
+				if (ap->vertical) {
+					XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+				    (int) (tri.x - ap->xs * fudge2 / 2),
+				    (int) (tri.y - 3 * ap->ys * fudge2 / 4),
+				    (unsigned int) (ap->xs * fudge2),
+				    (unsigned int) (3 * ap->ys * fudge2 / 2),
+				    (ang + fudge) * 64, (60 - 2 * fudge) * 64);
+				} else {
+					XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+				    (int) (tri.y - 3 * ap->ys * fudge2 / 4),
+				    (int) (tri.x - ap->xs * fudge2 / 2),
+				    (unsigned int) (3 * ap->ys * fudge2 / 2),
+				    (unsigned int) (ap->xs * fudge2),
+				    (ang + fudge) * 64, (60 - 2 * fudge) * 64);
+				}
 			}
 		}
 	}
@@ -888,8 +982,10 @@ getTable(ModeInfo * mi, int i)
 	total = ap->ncolors * ap->nstates;
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-			       "ants %d, neighbors %d, table number %d, colors %d, states %d\n",
-			  ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
+			"ants %d, neighbors %d, table number %d, colors %d, states %d\n",
+			ap->n, ap->neighbors, i, ap->ncolors, ap->nstates);
+	if (label)
+		(void) sprintf(ap->ruleString, "%d table number %d", ap->n, i);
 	for (j = 0; j < total; j++) {
 		status = &(ap->machine[j]);
 		status->color = *patptr++;
@@ -937,7 +1033,8 @@ static void
 getTurk(ModeInfo * mi, int logClass, int number)
 {
 	antfarmstruct *ap = &antfarms[MI_SCREEN(mi)];
-	int         power2, j, total;
+	int power2, j, total;
+	char rule[NUMSTIPPLES * STATES + 1];
 
 	power2 = 1 << (logClass - 1);
 	ap->ncolors = logClass;
@@ -954,15 +1051,20 @@ getTurk(ModeInfo * mi, int logClass, int number)
 				fromTableDirection(TRS, ap->neighbors) :
 				fromTableDirection(TLS, ap->neighbors);
 		}
+		rule[j] = ((power2 & number) ? 1 : 0) + '0';
 		ap->machine[j].next = 0;
 		power2 >>= 1;
 	}
+	rule[total] = '\0';
 	ap->truchet = (ap->truchet && ap->xs > 2 && ap->ys > 2 &&
 	   (ap->neighbors == 3 || ap->neighbors == 4 || ap->neighbors == 6));
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stdout,
-			"ants %d, neighbors %d, Turk's number 0x%x, colors %d\n",
-			ap->n, ap->neighbors, number, ap->ncolors);
+			"ants %d, neighbors %d, Turk's number 0x%x (%s), colors %d\n",
+			ap->n, ap->neighbors, number, rule, ap->ncolors);
+	if (label)
+		(void) sprintf(ap->ruleString, "%d Turk's number 0x%x",
+			ap->n, number);
 }
 
 static void
@@ -1086,10 +1188,24 @@ init_ant(ModeInfo * mi)
 			free(ap->ants);
 			ap->ants = (antstruct *) NULL;
 		}
-		ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;
+		/*ap->n = NRAND(-ap->n - MINANTS + 1) + MINANTS;*/
+		/* skew so that 1 is more likely */
+		ap->n = -ap->n - (int) (sqrt(NRAND(ap->n *ap->n - 1))) - 1 +
+			MINANTS;
 	} else if (ap->n < MINANTS)
 		ap->n = MINANTS;
 
+	if (MI_IS_FULLRANDOM(mi)) {
+		ap->truchet = (Bool) (LRAND() & 1);
+		ap->eyes = (Bool) (LRAND() & 1);
+		ap->sharpturn = (Bool) (LRAND() & 1);
+		ap->vertical = (Bool) (LRAND() & 1);
+	} else {
+		ap->truchet = truchet;
+		ap->eyes = eyes;
+		ap->sharpturn = sharpturn;
+		ap->vertical = vertical;
+	}
 	ap->width = MI_WIDTH(mi);
 	ap->height = MI_HEIGHT(mi);
 
@@ -1111,6 +1227,10 @@ init_ant(ModeInfo * mi)
 	if (ap->neighbors == 6) {
 		int         nccols, ncrows;
 
+		if (!ap->vertical) {
+			ap->height = MI_WIDTH(mi);
+			ap->width = MI_HEIGHT(mi);
+		}
 		if (ap->width < 8)
 			ap->width = 8;
 		if (ap->height < 8)
@@ -1137,8 +1257,19 @@ init_ant(ModeInfo * mi)
 		ap->xb = (ap->width - ap->xs * nccols) / 2 + ap->xs / 2;
 		ap->yb = (ap->height - ap->ys * (ncrows / 2) * 2) / 2 + ap->ys - 2;
 		for (i = 0; i < 6; i++) {
-			ap->shape.hexagon[i].x = (ap->xs - 1) * hexagonUnit[i].x;
-			ap->shape.hexagon[i].y = ((ap->ys - 1) * hexagonUnit[i].y / 2) * 4 / 3;
+			if (ap->vertical) {
+				ap->shape.hexagon[i].x =
+					(ap->xs - 1) * hexagonUnit[i].x;
+				ap->shape.hexagon[i].y =
+					((ap->ys - 1) * hexagonUnit[i].y /
+					2) * 4 / 3;
+			} else {
+				ap->shape.hexagon[i].y =
+					(ap->xs - 1) * hexagonUnit[i].x;
+				ap->shape.hexagon[i].x =
+					((ap->ys - 1) * hexagonUnit[i].y /
+					2) * 4 / 3;
+			}
 		}
 		/* Avoid array bounds read of hexagonUnit */
 		ap->shape.hexagon[6].x = 0;
@@ -1164,8 +1295,12 @@ init_ant(ModeInfo * mi)
 		ap->xb = (ap->width - ap->xs * ap->ncols) / 2;
 		ap->yb = (ap->height - ap->ys * ap->nrows) / 2;
 	} else {		/* TRI */
-		int         orient;
+		int orient;
 
+		if (!ap->vertical) {
+			ap->height = MI_WIDTH(mi);
+			ap->width = MI_HEIGHT(mi);
+		}
 		if (ap->width < 2)
 			ap->width = 2;
 		if (ap->height < 2)
@@ -1191,10 +1326,17 @@ init_ant(ModeInfo * mi)
 		ap->yb = (ap->height - ap->ys * ap->nrows) / 2 + ap->ys;
 		for (orient = 0; orient < 2; orient++) {
 			for (i = 0; i < 3; i++) {
-				ap->shape.triangle[orient][i].x =
-					(ap->xs - 2) * triangleUnit[orient][i].x;
-				ap->shape.triangle[orient][i].y =
-					(ap->ys - 2) * triangleUnit[orient][i].y;
+				if (ap->vertical) {
+					ap->shape.triangle[orient][i].x =
+						(ap->xs - 2) * triangleUnit[orient][i].x;
+					ap->shape.triangle[orient][i].y =
+						(ap->ys - 2) * triangleUnit[orient][i].y;
+				} else {
+					ap->shape.triangle[orient][i].y =
+						(ap->xs - 2) * triangleUnit[orient][i].x;
+					ap->shape.triangle[orient][i].x =
+						(ap->ys - 2) * triangleUnit[orient][i].y;
+				}
 			}
 			/* Avoid array bounds read of triangleUnit */
 			ap->shape.triangle[orient][3].x = 0;
@@ -1206,20 +1348,18 @@ init_ant(ModeInfo * mi)
 	MI_CLEARWINDOW(mi);
 	ap->painted = False;
 
-	if (MI_IS_FULLRANDOM(mi)) {
-		ap->truchet = (Bool) (LRAND() & 1);
-		ap->eyes = (Bool) (LRAND() & 1);
-		ap->sharpturn = (Bool) (LRAND() & 1);
-	} else {
-		ap->truchet = truchet;
-		ap->eyes = eyes;
-		ap->sharpturn = sharpturn;
-	}
+	ap->labelOffsetX = NRAND(8);
+	ap->labelOffsetY = NRAND(8);
 	parseRule(mi);
-	if (MI_NPIXELS(mi) > 2)
-		for (i = 0; i < (int) ap->ncolors - 1; i++)
-			ap->colors[i] = (unsigned char) (NRAND(MI_NPIXELS(mi)) +
-			     i * MI_NPIXELS(mi)) / ((int) (ap->ncolors - 1));
+	if (MI_NPIXELS(mi) > 2) {
+		int offset = NRAND(MI_NPIXELS(mi));
+
+		for (i = 0; i < (int) ap->ncolors - 1; i++) {
+			ap->colors[i] = (unsigned char) ((offset +
+				(i * MI_NPIXELS(mi) /
+				(int) (ap->ncolors - 1))) % MI_NPIXELS(mi));
+		}
+	}
 	if (ap->ants == NULL) {
 		if ((ap->ants = (antstruct *) malloc(ap->n * sizeof (antstruct))) ==
 				NULL) {
@@ -1227,7 +1367,7 @@ init_ant(ModeInfo * mi)
 			return;
 		}
 	}
-	if (ap->tape != NULL) 
+	if (ap->tape != NULL)
 		free(ap->tape);
 	if ((ap->tape = (unsigned char *) calloc(ap->ncols * ap->nrows,
 			sizeof (unsigned char))) == NULL) {
@@ -1357,6 +1497,23 @@ draw_ant(ModeInfo * mi)
 			}
 		}
 	}
+	if (label) {
+		int size = MAX(MIN(MI_WIDTH(mi), MI_HEIGHT(mi)) - 1, 1);
+
+		if (size >= 10 * FONT_WIDTH) {
+			/* hard code these to corners */
+			XSetForeground(MI_DISPLAY(mi), MI_GC(mi),
+				MI_WHITE_PIXEL(mi));
+			/*XDrawString(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+				16 + ap->labelOffsetX,
+				16 + ap->labelOffsetY + FONT_HEIGHT,
+				ap->ruleString, strlen(ap->ruleString)); */
+			XDrawString(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
+				16 + ap->labelOffsetX, MI_HEIGHT(mi) - 16 -
+				ap->labelOffsetY - FONT_HEIGHT / 2,
+				ap->ruleString, strlen(ap->ruleString));
+		}
+	}
 }
 
 void
