@@ -43,6 +43,7 @@ static const char sccsid[] = "@(#)blot.c	5.00 2000/11/01 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_blot
 #define PROGCLASS "Blot"
 #define HACK_INIT init_blot
 #define HACK_DRAW draw_blot
@@ -119,7 +120,7 @@ init_blot(ModeInfo * mi)
 	bp->size *= (bp->width / 32 + 1) * (bp->height / 32 + 1);
 	if (!bp->pointBuffer || bp->pointBufferSize < bp->size * sizeof (XPoint)) {
 		if (bp->pointBuffer != NULL)
-			(void) free((void *) bp->pointBuffer);
+			free(bp->pointBuffer);
 		bp->pointBufferSize = bp->size * sizeof (XPoint);
 		if ((bp->pointBuffer = (XPoint *) malloc(bp->pointBufferSize)) ==
 				NULL) {
@@ -197,11 +198,11 @@ release_blot(ModeInfo * mi)
 			blotstruct *bp = &blots[screen];
 
 			if (bp->pointBuffer != NULL) {
-				(void) free((void *) bp->pointBuffer);
+				free(bp->pointBuffer);
 				/* bp->pointBuffer == NULL; */
 			}
 		}
-		(void) free((void *) blots);
+		free(blots);
 		blots = (blotstruct *) NULL;
 	}
 }
