@@ -6,8 +6,6 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
 
 #endif
 
-#undef DEBUG_LISTS
-
 /*-
  * Permission to use, copy, modify, and distribute this software and its
  * documentation for any purpose and without fee is hereby granted,
@@ -44,7 +42,8 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * Marcelo F. Vianna (Jun-01-1997)
  *
  * Revision History:
- * 01-Mar-2001: backported from xscreensaver by lassauge@mail.dotcom.fr
+ * 05-Apr-2002: Removed all gllist uses (fix some bug with nvidia driver)
+ * 01-Mar-2001: backported from xscreensaver by lassauge AT users.sourceforge.net
  *    Feb-2001: Made motion and rotation be smoother Jamie Zawinski
  *              <jwz@jwz.org>
  * 01-Nov-2000: Allocation checks
@@ -79,16 +78,19 @@ static const char sccsid[] = "@(#)moebius.c	5.01 2001/03/01 xlockmore";
  * In real OpenGL, PseudoColor DO NOT support texture map (as far as I know).
  */
 
+#ifdef VMS
 #include <X11/Intrinsic.h>
+#endif
 
 #ifdef STANDALONE
+# define MODE_moebius
 # define PROGCLASS			"Moebius"
 # define HACK_INIT			init_moebius
 # define HACK_DRAW			draw_moebius
 # define HACK_RESHAPE			reshape_moebius
 # define moebius_opts			xlockmore_opts
 # define DEFAULTS			"*cycles:	1       \n"	\
-					"*delay:	20000   \n"	\
+					"*delay:	30000   \n"	\
 					"*showFps:      False   \n"	\
 					"*wireframe:	False	\n"
 # include "xlockmore.h"		/* from the xscreensaver distribution */
@@ -110,15 +112,15 @@ static int  noants;
 
 static XrmOptionDescRec opts[] =
 {
-  {(char *) "-solidmoebius", (char *) ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "on"},
-  {(char *) "+solidmoebius", (char *) ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "off"},
-  {(char *) "-noants", (char *) ".moebius.noants", XrmoptionNoArg, (caddr_t) "on"},
-  {(char *) "+noants", (char *) ".moebius.noants", XrmoptionNoArg, (caddr_t) "off"}
+	{(char *) "-solidmoebius", (char *) ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+solidmoebius", (char *) ".moebius.solidmoebius", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "-noants", (char *) ".moebius.noants", XrmoptionNoArg, (caddr_t) "on"},
+	{(char *) "+noants", (char *) ".moebius.noants", XrmoptionNoArg, (caddr_t) "off"}
 };
 static argtype vars[] =
 {
-  {(caddr_t *) & solidmoebius, (char *) "solidmoebius", (char *) "Solidmoebius", (char *) DEF_SOLIDMOEBIUS, t_Bool},
-  {(caddr_t *) & noants, (char *) "noants", (char *) "Noants", (char *) DEF_NOANTS, t_Bool}
+	{(void *) & solidmoebius, (char *) "solidmoebius", (char *) "Solidmoebius", (char *) DEF_SOLIDMOEBIUS, t_Bool},
+	{(void *) & noants, (char *) "noants", (char *) "Noants", (char *) DEF_NOANTS, t_Bool}
 
 };
 static OptionStruct desc[] =
@@ -134,7 +136,7 @@ ModeSpecOpt moebius_opts =
 ModStruct   moebius_description =
 {"moebius", "init_moebius", "draw_moebius", "release_moebius",
  "draw_moebius", "change_moebius", (char *) NULL, &moebius_opts,
- 1000, 1, 1, 1, 4, 1.0, "",
+ 30000, 1, 1, 1, 4, 1.0, "",
  "Shows Moebius Strip II, an Escher-like GL scene with ants", 0, NULL};
 
 #endif
@@ -158,7 +160,6 @@ typedef struct {
 	GLint       WindH, WindW;
 	GLfloat     step;
 	GLfloat     ant_position;
-	Bool        AreObjectsDefined[MaxObj];
 	GLXContext *glx_context;
 
   GLfloat rotx, roty, rotz;	   /* current object rotation */
@@ -209,7 +210,6 @@ static float MaterialGray8[] =
 {0.8, 0.8, 0.8, 1.0};
 
 static moebiusstruct *moebius = (moebiusstruct *) NULL;
-static GLuint objects = 0;
 
 #define NUM_SCENES      2
 
@@ -240,7 +240,7 @@ myCone(float radius)
 }
 
 static Bool
-draw_moebius_ant(moebiusstruct * mp, float *Material, int mono)
+draw_moebius_ant(float *Material, int mono)
 {
 	static float ant_step = 0;
 	float       cos1 = cos(ant_step);
@@ -254,50 +254,34 @@ draw_moebius_ant(moebiusstruct * mp, float *Material, int mono)
 		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray5);
 	else
 		glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, Material);
-	if (!mp->AreObjectsDefined[ObjAntBody]) {
-		glNewList(objects + ObjAntBody, GL_COMPILE_AND_EXECUTE);
-		if (glGetError() != GL_NO_ERROR) {
-			return False;
-		}
-		glEnable(GL_CULL_FACE);
-		glPushMatrix();
-		glScalef(1, 1.3, 1);
-		if (!mySphere(0.18))
-			return False;
-		glScalef(1, 1 / 1.3, 1);
-		glTranslatef(0.00, 0.30, 0.00);
-		if (!mySphere(0.2))
-			return False;
+	glEnable(GL_CULL_FACE);
+	glPushMatrix();
+	glScalef(1, 1.3, 1);
+	if (!mySphere(0.18))
+		return False;
+	glScalef(1, 1 / 1.3, 1);
+	glTranslatef(0.00, 0.30, 0.00);
+	if (!mySphere(0.2))
+		return False;
 
-		glTranslatef(-0.05, 0.17, 0.05);
-		glRotatef(-90, 1, 0, 0);
-		glRotatef(-25, 0, 1, 0);
-		if (!myCone(0.05))
-			return False;
-		glTranslatef(0.00, 0.10, 0.00);
-		if (!myCone(0.05))
-			return False;
-		glRotatef(25, 0, 1, 0);
-		glRotatef(90, 1, 0, 0);
+	glTranslatef(-0.05, 0.17, 0.05);
+	glRotatef(-90, 1, 0, 0);
+	glRotatef(-25, 0, 1, 0);
+	if (!myCone(0.05))
+		return False;
+	glTranslatef(0.00, 0.10, 0.00);
+	if (!myCone(0.05))
+		return False;
+	glRotatef(25, 0, 1, 0);
+	glRotatef(90, 1, 0, 0);
 
-		glScalef(1, 1.3, 1);
-		glTranslatef(0.15, -0.65, 0.05);
-		if (!mySphere(0.25))
-			return False;
-		glScalef(1, 1 / 1.3, 1);
-		glPopMatrix();
-		glDisable(GL_CULL_FACE);
-		glEndList();
-		mp->AreObjectsDefined[ObjAntBody] = True;
-#ifdef DEBUG_LISTS
-		(void) printf("Ant drawn SLOWLY\n");
-#endif
-	} else {
-		glCallList(objects + ObjAntBody);
-#ifdef DEBUG_LISTS
-		(void) printf("Ant drawn quickly\n");
-#endif
-	}
+	glScalef(1, 1.3, 1);
+	glTranslatef(0.15, -0.65, 0.05);
+	if (!mySphere(0.25))
+		return False;
+	glScalef(1, 1 / 1.3, 1);
+	glPopMatrix();
+	glDisable(GL_CULL_FACE);
 
 	glDisable(GL_LIGHTING);
 	/* ANTENNAS */
@@ -451,13 +435,35 @@ draw_moebius_strip(ModeInfo * mi)
 
 	float       Cx, Cy, Cz;
 
-	if (!mp->AreObjectsDefined[ObjMoebiusStrip]) {
-		glNewList(objects + ObjMoebiusStrip, GL_COMPILE_AND_EXECUTE);
-		if (glGetError() != GL_NO_ERROR) {
-			return False;
-		}
+	if (solidmoebius) {
+		glBegin(GL_QUAD_STRIP);
+		Phi = 0;
+		i = 0;
+		while (i < (MoebiusDivisions * 2 + 1)) {
+			Theta = Phi / 2;
+			cPhi = cos(Phi);
+			sPhi = sin(Phi);
 
-		if (solidmoebius) {
+			i++;
+			if (mono)
+				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
+			else if (i % 2)
+				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
+			else
+				glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
+
+			RotateAaroundU(cPhi, sPhi, 0, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
+			glNormal3f(Cx, Cy, Cz);
+			RotateAaroundU(0, 0, 1, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
+			glVertex3f(cPhi * 3 + Cx, sPhi * 3 + Cy, +Cz);
+			glVertex3f(cPhi * 3 - Cx, sPhi * 3 - Cy, -Cz);
+
+			Phi += Pi / MoebiusDivisions;
+		}
+		glEnd();
+	} else {
+		for (j = -MoebiusTransversals; j < MoebiusTransversals; j++) {
+			glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
 			glBegin(GL_QUAD_STRIP);
 			Phi = 0;
 			i = 0;
@@ -466,72 +472,32 @@ draw_moebius_strip(ModeInfo * mi)
 				cPhi = cos(Phi);
 				sPhi = sin(Phi);
 
-				i++;
-				if (mono)
+				RotateAaroundU(cPhi, sPhi, 0, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
+				glNormal3f(Cx, Cy, Cz);
+				RotateAaroundU(0, 0, 1, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
+				j++;
+				if (j == MoebiusTransversals || mono)
 					glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
 				else if (i % 2)
 					glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
 				else
 					glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
-
-				RotateAaroundU(cPhi, sPhi, 0, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
-				glNormal3f(Cx, Cy, Cz);
-				RotateAaroundU(0, 0, 1, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
-				glVertex3f(cPhi * 3 + Cx, sPhi * 3 + Cy, +Cz);
-				glVertex3f(cPhi * 3 - Cx, sPhi * 3 - Cy, -Cz);
+				glVertex3f(cPhi * 3 + Cx / MoebiusTransversals * j, sPhi * 3 + Cy / MoebiusTransversals * j, +Cz / MoebiusTransversals * j);
+				j--;
+				if (j == -MoebiusTransversals || mono)
+					glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
+				else if (i % 2)
+					glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
+				else
+					glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
+				glVertex3f(cPhi * 3 + Cx / MoebiusTransversals * j, sPhi * 3 + Cy / MoebiusTransversals * j, +Cz / MoebiusTransversals * j);
 
 				Phi += Pi / MoebiusDivisions;
+				i++;
 			}
 			glEnd();
-		} else {
-			for (j = -MoebiusTransversals; j < MoebiusTransversals; j++) {
-				glPolygonMode(GL_FRONT_AND_BACK, GL_LINE);
-				glBegin(GL_QUAD_STRIP);
-				Phi = 0;
-				i = 0;
-				while (i < (MoebiusDivisions * 2 + 1)) {
-					Theta = Phi / 2;
-					cPhi = cos(Phi);
-					sPhi = sin(Phi);
-
-					RotateAaroundU(cPhi, sPhi, 0, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
-					glNormal3f(Cx, Cy, Cz);
-					RotateAaroundU(0, 0, 1, -sPhi, cPhi, 0, &Cx, &Cy, &Cz, Theta);
-					j++;
-					if (j == MoebiusTransversals || mono)
-						glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
-					else if (i % 2)
-						glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
-					else
-						glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
-					glVertex3f(cPhi * 3 + Cx / MoebiusTransversals * j, sPhi * 3 + Cy / MoebiusTransversals * j, +Cz / MoebiusTransversals * j);
-					j--;
-					if (j == -MoebiusTransversals || mono)
-						glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialWhite);
-					else if (i % 2)
-						glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialRed);
-					else
-						glMaterialfv(GL_FRONT_AND_BACK, GL_DIFFUSE, MaterialGray);
-					glVertex3f(cPhi * 3 + Cx / MoebiusTransversals * j, sPhi * 3 + Cy / MoebiusTransversals * j, +Cz / MoebiusTransversals * j);
-
-					Phi += Pi / MoebiusDivisions;
-					i++;
-				}
-				glEnd();
-			}
-			glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
 		}
-
-		glEndList();
-		mp->AreObjectsDefined[ObjMoebiusStrip] = True;
-#ifdef DEBUG_LISTS
-		(void) printf("Strip drawn SLOWLY\n");
-#endif
-	} else {
-		glCallList(objects + ObjMoebiusStrip);
-#ifdef DEBUG_LISTS
-		(void) printf("Strip drawn quickly\n");
-#endif
+		glPolygonMode(GL_FRONT_AND_BACK, GL_FILL);
 	}
 
 	if (!noants) {
@@ -541,7 +507,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glTranslatef(3, 0, 0);
 		glRotatef(mp->ant_position / 2 + 90, 0, 1, 0);
 		glTranslatef(0.28, 0, -0.45);
-		if (!draw_moebius_ant(mp, MaterialYellow, mono))
+		if (!draw_moebius_ant(MaterialYellow, mono))
 			return False;
 		glPopMatrix();
 
@@ -551,7 +517,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glTranslatef(3, 0, 0);
 		glRotatef(mp->ant_position / 2, 0, 1, 0);
 		glTranslatef(0.28, 0, -0.45);
-		if (!draw_moebius_ant(mp, MaterialBlue, mono))
+		if (!draw_moebius_ant(MaterialBlue, mono))
 			return False;
 		glPopMatrix();
 
@@ -562,7 +528,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glRotatef(-mp->ant_position / 2, 0, 1, 0);
 		glTranslatef(0.28, 0, 0.45);
 		glRotatef(180, 1, 0, 0);
-		if (!draw_moebius_ant(mp, MaterialGreen, mono))
+		if (!draw_moebius_ant(MaterialGreen, mono))
 			return False;
 		glPopMatrix();
 
@@ -573,7 +539,7 @@ draw_moebius_strip(ModeInfo * mi)
 		glRotatef(-mp->ant_position / 2 + 90, 0, 1, 0);
 		glTranslatef(0.28, 0, 0.45);
 		glRotatef(180, 1, 0, 0);
-		if (!draw_moebius_ant(mp, MaterialCyan, mono))
+		if (!draw_moebius_ant(MaterialCyan, mono))
 			return False;
 		glPopMatrix();
 	}
@@ -603,8 +569,6 @@ reshape_moebius(ModeInfo * mi, int width, int height)
 		glLineWidth(1);
 		glPointSize(1);
 	}
-	mp->AreObjectsDefined[ObjMoebiusStrip] = False;
-	mp->AreObjectsDefined[ObjAntBody] = False;
 }
 
 static void
@@ -729,13 +693,9 @@ void
 release_moebius(ModeInfo * mi)
 {
 	if (moebius != NULL) {
-		(void) free((void *) moebius);
+		free(moebius);
 		moebius = (moebiusstruct *) NULL;
 	}
-	if (glIsList(objects)) {
-		glDeleteLists(objects, MaxObj);
-		objects = 0;
-	}
 	FreeAllGL(mi);
 }
 
@@ -776,12 +736,6 @@ init_moebius(ModeInfo * mi)
 
 		reshape_moebius(mi, MI_WIDTH(mi), MI_HEIGHT(mi));
 		glDrawBuffer(GL_BACK);
-		if (!glIsList(objects))
-			if ((objects = glGenLists(MaxObj)) == 0) {
-				MI_CLEARWINDOW(mi);
-				release_moebius(mi);
-				return;
-			}
 		pinit();
 	} else {
 		MI_CLEARWINDOW(mi);
@@ -839,11 +793,11 @@ draw_moebius(ModeInfo * mi)
 
 	glPopMatrix();
 
-    rotate(&mp->rotx, &mp->dx, &mp->ddx, mp->d_max, MI_IS_VERBOSE(mi));
-    rotate(&mp->roty, &mp->dy, &mp->ddy, mp->d_max, MI_IS_VERBOSE(mi));
-    rotate(&mp->rotz, &mp->dz, &mp->ddz, mp->d_max, MI_IS_VERBOSE(mi));
+	rotate(&mp->rotx, &mp->dx, &mp->ddx, mp->d_max, MI_IS_VERBOSE(mi));
+	rotate(&mp->roty, &mp->dy, &mp->ddy, mp->d_max, MI_IS_VERBOSE(mi));
+	rotate(&mp->rotz, &mp->dz, &mp->ddz, mp->d_max, MI_IS_VERBOSE(mi));
 
-    if (MI_IS_FPS(mi)) do_fps (mi);
+	if (MI_IS_FPS(mi)) do_fps (mi);
 	glFlush();
 
 	glXSwapBuffers(display, window);
