@@ -18,7 +18,7 @@
  * 02-Jun-2004: Lots more lifeforms.
  * 16-Apr-2004: S45B5 shower, blob with stabilizers, big pinwheel,
  *              pulsar 10, pulsar 20
- * 15-Apr-2004: S45B5 linked glider, 123243, dancing beacon, Lq 
+ * 15-Apr-2004: S45B5 linked glider, 123243, dancing beacon, Lq
  *              S567B6 sparky, fountain, cruncher, big star, mouth
  *              S56B5 double switch
  *              S678B5 waving tail, deformed runner
@@ -32,13 +32,1159 @@
  *
  */
 
-#define MAXNEIGHBORS 27
+#define MAXNEIGHBORS 26
+#define NEIGHBORKINDS 7
 #define NUMPTS 42
 
 typedef struct {
 	int         survival, birth;
 } paramstruct;
 
+static char plots[NEIGHBORKINDS] =
+{
+	6, 8, 12, 14, 18, 20, 26	/* Neighborhoods */
+};
+
+static char patterns_12S3B3[][3 * NUMPTS + 1] =
+{
+#ifdef LIFE_NAMES
+	{"2-A (p2)"},
+#endif
+	{
+		0, 0, -1,
+		-1, 1, -1,
+
+		0, -1, 0,
+		1, 0, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-B (p2)"},
+#endif
+	{
+		-1, -1, -1,
+		0, 0, -1,
+
+		0, -1, 0,
+		1, 0, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-C (p2)"},
+#endif
+	{
+		-1, -1, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-D (p4)"},
+#endif
+	{
+		-1, -1, -1,
+		0, 0, -1,
+
+		1, -2, 0,
+		-1, 0, 0,
+		0, 1, 0,
+
+		-1, -1, 1,
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"DD (p4)"},
+#endif
+	{
+		-4, 0, -1, 4, 0, -1,
+
+		-1, 0, 0, 1, 0, 0,
+		-2, -1, 0, 2, -1, 0,
+		-2, 1, 0, 2, 1, 0,
+
+		-3, -1, 1, 3, -1, 1,
+		-2, 0, 1, 2, 0, 1,
+		-3, 1, 1, 3, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-E (p2)"},
+#endif
+	{
+		0, 0, -1,
+
+		0, -1, 0,
+		1, 0, 0,
+
+		-1, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-G (p2)"},
+#endif
+	{
+		-1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-H (p2)"},
+#endif
+	{
+		-1, -1, -1, 1, -1, -1,
+		0, 0, -1, 2, 0, -1,
+		1, 1, -1,
+		2, 2, -1,
+
+		0, -2, 1,
+		1, -1, 1,
+		0, 0, 1, 2, 0, 1,
+		1, 1, 1, 3, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-I (p2)"},
+#endif
+	{
+		-2, 0, -1,
+		-1, 1, -1,
+
+		-1, -2, 0,
+		-2, -1, 0,
+		1, 0, 0,
+		0, 1, 0,
+
+		-2, 0, 1,
+		-1, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"3-A (p2)"},
+#endif
+	{
+		1, 1, -1,
+
+		1, 0, 0,
+		0, 1, 0,
+
+		1, -1, 1,
+		-1, 1, 1,
+
+		1, -2, 2,
+		0, -1, 2,
+		-1, 0, 2,
+		-2, 1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"3-B (p2)"},
+#endif
+	{
+		0, -1, -2,
+		-1, 0, -2, 1, 0, -2,
+		-2, 1, -2, 2, 1, -2,
+
+		-1, 1, -1, 1, 1, -1,
+
+		0, 1, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"3-C (p2)"},
+#endif
+	{
+		1, -3, -3,
+		0, -2, -3,
+		-1, -1, -3,
+		-2, 0, -3,
+
+		1, -2, -2,
+		-1, 0, -2,
+
+		3, -3, -1,
+		2, -2, -1,
+		-1, 1, -1,
+		-2, 2, -1,
+
+		3, -2, 0,
+		-1, 2, 0,
+
+		3, -1, 1,
+		2, 0, 1,
+		1, 1, 1,
+		0, 2, 1,
+
+		1, 2, 2,
+		3, 0, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"3-D (p2)"},
+#endif
+	{
+		-3, -3, -3,
+		-1, -1, -3,
+		1, 1, -3,
+		3, 3, -3,
+
+		-4, -3, -2,
+		-3, -2, -2,
+		-2, -1, -2,
+		-1, 0, -2,
+		0, 1, -2,
+		1, 2, -2,
+		2, 3, -2,
+		3, 4, -2,
+
+		-5, -3, -1,
+		3, 5, -1,
+
+		-4, -3, 0,
+		-3, -2, 0,
+		-2, -1, 0,
+		-1, 0, 0,
+		0, 1, 0,
+		1, 2, 0,
+		2, 3, 0,
+		3, 4, 0,
+
+		-3, -3, 1,
+		-1, -1, 1,
+		1, 1, 1,
+		3, 3, 1,
+		127
+	},
+#if 0
+/* still life */
+#ifdef LIFE_NAMES
+	{"4-A"},
+#endif
+	{
+		-1, -1, -1,
+		0, 0, -1,
+
+		0, -1, 0,
+		-1, 0, 0,
+		127
+	},
+#endif
+#ifdef LIFE_NAMES
+	{"4-F"},
+#endif
+	{
+		-2, -2, -3,
+		1, -1, -3,
+		-1, 1, -3,
+		2, 2, -3,
+
+		1, -2, -2,
+		0, -1, -2, 2, -1, -2,
+		-1, 0, -2, 1, 0, -2,
+		-2, 1, -2, 0, 1, -2,
+		-1, 2, -2,
+
+		-1, -1, -1, 1, -1, -1,
+		-1, 1, -1, 1, 1, -1,
+
+		-1, -2, 0,
+		-2, -1, 0, 0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		1, 2, 0,
+
+		2, -2, 1,
+		-1, -1, 1,
+		1, 1, 1,
+		-2, 2, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"4-H"},
+#endif
+	{
+		0, 0, -1,
+		1, 1, -1,
+
+		0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		1, 2, 0,
+
+		1, -1, 1,
+		0, 0, 1, 2, 0, 1,
+		-1, 1, 1, 1, 1, 1,
+		0, 2, 1,
+
+		1, 0, 2,
+		0, 1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"5-A"},
+#endif
+	{
+		0, -1, -2,
+
+		-2, -2, -1,
+		-1, -1, -1,
+		0, 0, -1,
+		1, 1, -1,
+
+		-2, -1, 0,
+		0, 1, 0,
+
+		-3, -1, 1,
+		-2, 0, 1,
+		-1, 1, 1,
+		0, 2, 1,
+
+		-2, 1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"5-B"},
+#endif
+	{
+		-2, -1, -2, 0, -1, -2,
+		-1, 0, -2, 1, 0, -2,
+		0, 1, -2, 1, 2, -2,
+
+		-2, -2, -1, 0, -2, -1,
+		1, -1, -1,
+		2, 0, -1,
+		2, 2, -1,
+
+		-1, -2, 0, 0, -2, 1, 1, -2, 0,
+		2, -1, 0,
+		-1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+
+		0, 0, 1, 2, 0, 1,
+
+		2, -1, 2,
+		1, -2, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"6-C"},
+#endif
+	{
+		0, 0, -3,
+
+		-1, -2, -2,
+		0, -1, -2,
+		1, 0, -2,
+		2, 1, -2,
+
+		-1, -1, -1,
+		-2, 0, -1,
+		1, 1, -1,
+		0, 2, -1,
+
+		-1, 0, 0,
+		0, 1, 0,
+
+		-1, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"7-G Mitosis (p4)"},
+#endif
+	{
+		0, 1, -4,
+		-2, 1, -2, 2, 1, -2,
+		-1, 2, -2, 1, 2, -2,
+
+		-1, 1, -1, 1, 1, -1,
+		-2, 2, -1, 2, 2, -1,
+		0, 4, -1,
+
+		0, -3, 0,
+		-2, -1, 0, 2, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+
+		-1, -1, 1, 1, -1, 1,
+		-2, 0, 1, 2, 0, 1,
+
+		0, 0, 3,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"5-C Metamorphosis (p6)"},
+#endif
+	{
+		-1, -2, -2, 1, -2, -2,
+		-2, -1, -2, 0, -1, -2, 2, -1, -2,
+		-1, 0, -2, 1, 0, -2,
+		-2, 1, -2, 0, 1, -2, 2, 1, -2,
+		-1, 2, -2, 1, 2, -2,
+
+		0, -2, -1,
+		-2, 0, -1, 2, 0, -1,
+		0, 2, -1,
+
+		0, -3, 0,
+		-3, 0, 0, 3, 0, 0,
+		0, 3, 0,
+		127
+	},
+#if 0
+#ifdef LIFE_NAMES
+	{"2-N, little glider (p2, diag)"},
+#endif
+	{
+		0, 0, -1,
+		-1, 1, -1,
+
+		0, -1, 0,
+		1, 0, 0,
+		-1, 2, 0,
+
+		0, 0, 1,
+		-1, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"2-O, big glider (p2, diag)"},
+#endif
+	{
+		2, -2, -1,
+		1, -1, -1,
+
+		2, -3, 0,
+		3, -2, 0,
+		-1, 0, 0,
+		-2, 1, 0, 0, 1, 0,
+		-1, 2, 0,
+
+		2, -2, 1,
+		1, -1, 1,
+		127
+	},
+#endif
+};
+
+static char patterns_12S456B3[][3 * NUMPTS + 1] =
+{
+#if 0
+#ifdef LIFE_NAMES
+	{"blinker (p2)"},
+#endif
+	{
+		1, 1, -1,
+
+		-1, 0, 0, 0, -1, 0,
+
+		1, 1, 1,
+		127
+	},
+#endif
+#ifdef LIFE_NAMES
+	{"hex (p2)"},
+#endif
+	{
+		1, -1, -1,
+		0, 0, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0,
+
+		0, -2, 1,
+		-1, -1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"blinker2 (p2)"},
+#endif
+	{
+		-1, -1, -1, 1, -1, -1,
+		0, 0, -1,
+		0, -2, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"double blinker2 (p2)"},
+#endif
+	{
+		-2, -1, 0, 0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		-1, -2, 0, 1, 2, 0,
+
+		0, -2, 1,
+		-1, -1, 1,
+		-2, 0, 1, 2, 0, 1,
+		1, 1, 1,
+		0, 2, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"clock (p4)"},
+#endif
+	{
+		0, 0, -1,
+
+		-1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0,
+		-1, 2, 0, 1, 2, 0,
+
+		1, -1, 1,
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"corner (p6)"},
+#endif
+	{
+		0, -2, -3, 2, -2, -3,
+		1, -1, -3,
+		-2, 0, -3,
+		-1, 1, -3,
+		-2, 2, -3,
+
+		-2, -3, 2, 0, -3, -2, 2, -3, -2,
+		0, -1, -2, 2, -1, -2,
+		-3, 0, -2, -1, 0, -2, 1, 0, -2,
+		0, 1, -2,
+		-3, 2, -2, -1, 2, -2,
+
+		1, -3, -1,
+		0, -2, -1, 2, -2, -1,
+		-2, 0, -1,
+		-3, 1, -1,
+		-2, 2, -1,
+
+		-2, -3, 0,
+		-3, -2, 0, -1, -2, 0,
+		1, -2, 0,
+		-2, -1, 0,
+		-2, 1, 0,
+
+		-1, -3, 1,
+		0, -2, 1,
+		-3, -1, 1,
+		-2, 0, 1,
+
+		-3, -2, 2, -1, -2, 2,
+		-2, -1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"A (p4)"},
+#endif
+	{
+		-1, -1, -1,
+		0, 0, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0,
+
+		-2, 0, 1,
+		-1, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"B (p4)"},
+#endif
+	{
+		-1, -1, -1,
+		0, 0, -1,
+		1, 1, -1,
+
+		1, -2, 0,
+		0, -1, 0, 2, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		-2, 1, 0, 0, 1, 0,
+		-1, 2, 0,
+
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"C (p6)"},
+#endif
+	{
+		0, -1, -2,
+		0, 1, -2,
+
+		0, 0, -1,
+
+		-2, -1, 0, 0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		-2, 1, 0, 0, 1, 0,
+
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"D (p12)"},
+#endif
+	{
+		0, -2, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0,
+		0, 1, 0,
+
+		1, -1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"E (p4)"},
+#endif
+	{
+		-1, -1, -1,
+		0, 0, -1,
+		1, 1, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		-2, 1, 0, 0, 1, 0,
+
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"F (p3)"},
+#endif
+	{
+		-2, -2, -3,
+		-3, -1, -3, -1, -1, -3,
+		-2, 0, -3,
+
+		-3, -2, -2, -1, -2, -2,
+		-3, 0, -2, -1, 0, -2,
+
+		-2, -2, -1,
+		-3, -1, -1, -1, -1, -1,
+		-2, 0, -1,
+
+		1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		1, 2, 0,
+
+		0, 0, 1, 2, 0, 1,
+		0, 2, 1, 2, 2, 1,
+
+		1, 0, 2,
+		0, 1, 2, 2, 1, 2,
+		1, 2, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"G (p8)"},
+#endif
+	{
+		-1, -2, -2,
+		2, 1, -2,
+
+		-1, -1, -1,
+		1, 1, -1,
+
+		-1, -2, 0,
+		-2, -1, 0, 0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		1, 2, 0,
+
+		-1, -1, 1,
+		1, 1, 1,
+
+		-1, -2, 2,
+		-1, 0, 2,
+		0, 1, 2, 2, 1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"H (p4)"},
+#endif
+	{
+		0, -2, -1,
+		-3, -1, -1, -1, -1, -1,
+		2, 0, -1,
+		1, 1, -1,
+		1, 3, -1,
+
+		-1, -2, 0,
+		-2, -1, 0, 0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0, 2, 1, 0,
+		1, 2, 0,
+
+		-2, -2, 1,
+		-1, -1, 1,
+		1, 1, 1,
+		2, 2, 1,
+		127
+	},
+#if 0
+/* seems like M */
+#ifdef LIFE_NAMES
+	{"I (p4)"},
+#endif
+	{
+		0, -2, -3,
+		-2, 0, -3,
+
+		-1, -2, -2,
+		-2, -1, -2, 0, -1, -2,
+		-1, 0, -2,
+
+		-1, -3, -1,
+		0, -2, -1, 2, -2, -1,
+		-3, -1, -1, 1, -1, -1,
+		-2, 0, -1,
+		-1, 1, -1,
+		-2, 2, -1,
+
+		0, -3, 0,
+		1, -2, 0,
+		-3, 0, 0, 1, 0, 0,
+		-2, 1, 0, 0, 1, 0,
+
+		1, -1, 1,
+		0, 0, 1, 2, 0, 1,
+		-1, 1, 1,
+		0, 2, 1,
+
+		0, -1, 2,
+		-1, 0, 2,
+		127
+	},
+#endif
+#ifdef LIFE_NAMES
+	{"M (p)"},
+#endif
+	{
+		-2, -1, -2, 0, -1, -2,
+		-1, 0, -2,
+		0, 1, -2,
+
+		-2, -2, -1, 0, -2, -1,
+		1, -1, -1,
+		-2, 0, -1,
+		-1, 1, -1, 1, 1, -1,
+
+		-1, -2, 0,
+		-2, -1, 0,
+		1, 0, 0,
+		0, 1, 0,
+
+		0, -2, 1,
+		-1, -1, 1, 1, -1, 1,
+		0, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"P (p30)"},
+#endif
+	{
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0,
+		0, 1, 0,
+		-1, 2, 0,
+
+		1, -3, 1,
+		0, -2, 1,
+		1, -1, 1,
+		0, 0, 1,
+		-1, 1, 1,
+		127
+	},
+#if 0
+#ifdef LIFE_NAMES
+	{"glider (p2 c/2 full diagnoal)"},
+#endif
+	{
+		0, -2, -1,
+		1, -1, -1,
+		0, 0, -1,
+		1, 1, -1,
+
+		0, -1, 0,
+		1, 0, 0,
+
+		0, -2, 1,
+		1, 1, 1,
+		127
+	},
+#endif
+};
+
+/* Bays' calls this Life.011 4544, ie. an 18 cell neighbhood */
+static char patterns_18S45B4[][3 * NUMPTS + 1] =
+{
+#if 0
+#ifdef LIFE_NAMES
+	{"blinker (p2)"},
+#endif
+	{
+		0, 0, -1, -1, 0, -1,
+		0, -1, 0, -1, -1, 0,
+		127
+	},
+#endif
+#ifdef LIFE_NAMES
+	{"helicopter (p2)"},
+#endif
+	{
+		1, -1, -1,
+		1, 1, -1,
+
+		0, 0, 0, 1, 0, 0, 2, 0, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"couch (p2)"},
+#endif
+	{
+		-2, 0, -1, 1, 0, -1,
+		0, -1, -1, -1, -1, -1,
+		-2, -1, 0, 1, -1, 0,
+		-2, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"twisty (p2)"},
+#endif
+	{
+		-1, 0, -2, 0, 0, -2,
+
+		0, -2, -1,
+		1, -1, -1,
+		0, 1, -1, -1, 1, -1,
+
+		0, -2, 0,
+		-2, -1, 0, 1, -1, 0,
+		-2, 0, 0,
+
+		-1, -1, 1,
+		-1, 0, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"ball (p2)"},
+#endif
+	{
+		1, 1, -1,
+
+		1, 0, 0, 2, 0, 0,
+		0, 1, 0, 1, 1, 0,
+		0, 2, 0,
+
+		1, -1, 1,
+		0, 0, 1, 1, 0, 1,
+		-1, 1, 1, 0, 1, 1,
+
+		0, 0, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"death star (p2)"},
+#endif
+	{
+		0, 0, -2,
+
+		0, -1, -1,
+		-1, 0, -1,
+		0, 1, -1,
+
+		0, -2, 0,
+		-1, -1, 0, 1, -1, 0,
+		-2, 0, 0, 2, 0, 0,
+		1, 1, 0,
+		0, 2, 0,
+
+		-1, 0, 1, 1, 0, 1,
+		0, 1, 1,
+
+		0, 0, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"corner (p4)"},
+#endif
+	{
+		0, 1, -2,
+
+		2, -1, -1,
+		1, 0, -1, 2, 0, -1,
+		0, 1, -1,
+		-1, 2, -1,
+
+		1, -2, 0,
+		1, -1, 0,
+		-1, 1, 0,
+		-1, 2, 0,
+
+		-2, 0, 1, -1, 0, 1,
+		0, -1, 1,
+
+		-1, -1, 2, 0, -1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"Hogwart stairway (p8)"},
+#endif
+	{
+		1, -2, -1,
+		0, -1, -1,
+		-1, 0, -1,
+		-2, 1, -1,
+
+		1, -2, 0,
+		0, -1, 0,
+		-1, 0, 0,
+		-2, 1, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"X (p38)"},
+#endif
+	{
+		0, -1, -1,
+		-1, 0, -1, 0, 0, -1, 1, 0, -1,
+		0, 1, -1,
+
+		0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0,
+		127
+	},
+#if 0
+#ifdef LIFE_NAMES
+	{"glider (p2 c/2)"},
+#endif
+	{
+		-1, -2, -1, 0, -2, -1,
+		0, -1, -1,
+		0, 0, -1,
+		-1, 1, -1, 0, 1, -1,
+
+		-1, -2, 0, 0, -2, 0,
+		0, -1, 0,
+		0, 0, 0,
+		-1, 1, 0, 0, 1, 0,
+		127
+	}
+#endif
+};
+
+/* Bays' calls this Life.110 4544, ie. a 20 cell neighbhood */
+static char patterns_20S45B4[][3 * NUMPTS + 1] =
+{
+#if 0
+#ifdef LIFE_NAMES
+	{"blinker (p2)"},
+#endif
+	{
+		-1, 0, -1, 1, 0, -1,
+		-1, 0, 0, 1, 0, 0,
+		127
+	},
+#endif
+#ifdef LIFE_NAMES
+	{"pillars (p2)"},
+#endif
+	{
+		-1, -2, -1, 0, -2, -1,
+		-1, 1, -1, 0, 1, -1,
+
+		-1, -2, 1, 0, -2, 1,
+		-1, 1, 1, 0, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"window (p2)"},
+#endif
+	{
+		-1, -1, -1, 0, -1, -1,
+		-1, 1, -1, 0, 1, -1,
+		-1, -1, 0, 0, -1, 0,
+		-1, 1, 0, 0, 1, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"stargate (p2)"},
+#endif
+	{
+		0, 0, -4,
+
+		0, 0, -3,
+
+		-2, 0, -2, 0, 0, -2, 2, 0, -2,
+
+		-4, 0, 0, -3, 0, 0, -2, 0, 0, 2, 0, 0, 3, 0, 0, 4, 0, 0,
+
+		-2, 0, 2, 0, 0, 2, 2, 0, 2,
+
+		0, 0, 3,
+
+		0, 0, 4,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"rock and window (p2)"},
+#endif
+	{
+		-1, -1, -3, 0, -1, -3,
+		-1, 0, -3, 0, 0, -3,
+
+		0, -2, -1,
+		1, -1, -1,
+		1, 0, -1,
+
+		-1, -2, -1,
+		-2, -1, -1,
+		-2, 0, -1,
+		-1, 1, -1, 0, 1, -1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"alternator (p2)"},
+#endif
+	{
+		-1, -2, -2, 0, -2, -2,
+		-1, 1, -2, 0, 1, -2,
+
+		-1, -3, -1, 0, -3, -1,
+		-2, -2, -1, 1, -2, -1,
+		-2, -1, -1, 1, -1, -1,
+		-2, 0, -1, 1, 0, -1,
+		-2, 1, -1, 1, 1, -1,
+		-1, 2, -1, 0, 2, -1,
+
+		-1, -3, 0, 0, -3, 0,
+		-2, -2, 0, 1, -2, 0,
+		-2, -1, 0, 1, -1, 0,
+		-2, 0, 0, 1, 0, 0,
+		-2, 1, 0, 1, 1, 0,
+		-1, 2, 0, 0, 2, 0,
+
+		-1, -2, 1, 0, -2, 1,
+		-1, 1, 1, 0, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"exploding wheel (p3)"},
+#endif
+	{
+		0, 0, -3,
+
+		0, -2, -2,
+		-2, 0, -2, 2, 0, -2,
+		0, 2, -2,
+
+		0, -1, -1,
+		-1, 0, -1, 1, 0, -1,
+		0, 1, -1,
+
+		0, -1, 0,
+		-1, 0, 0, 1, 0, 0,
+		0, 1, 0,
+
+		0, -2, 1,
+		-2, 0, 1, 2, 0, 1,
+		0, 2, 1,
+
+		0, 0, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"fish (p3)"},
+#endif
+	{
+		-2, -1, -2, -1, -2, -2, 0, -1, -2,
+		-1, 0, -2,
+
+		-2, -2, -1, 0, -2, -1,
+		-2, 0, -1, 1, 0, -1,
+		0, 1, -1,
+
+		-1, -2, 0,
+		-2, -1, 0, -1, 1, 0, 0, 1, 0, 1, -1, 0,
+		1, 0, 0,
+
+		-1, 0, 1, 0, 0, 1,
+		0, -1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"flipping triangles (p4)"},
+#endif
+ {
+		-1, -1, -1, 0, -1, -1, 1, -1, -1,
+		-1, 0, -1, 0, 0, -1,
+		-1, 1, -1,
+
+		-1, -1, 1, 0, -1, 1, 1, -1, 1,
+		-1, 0, 1, 0, 0, 1,
+		-1, 1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"shuttle (p4)"},
+#endif
+	{
+		-1, -1, -2, 0, -1, -2,
+		-1, 0, -2,
+
+		-1, -2, -1, 0, -2, -1,
+		-2, -1, -1,
+		-2, 0, -1, 1, 0, -1,
+		0, 1, -1,
+
+		-1, -2, 0,
+		-2, -1, 0, 1, -1, 0,
+		2, 0, 0,
+		-1, 1, 0, 2, 1, 0,
+		0, 2, 0, 1, 2, 0,
+
+		0, -1, 1,
+		-1, 0, 1, 2, 0, 1,
+		2, 1, 1,
+		0, 2, 1, 1, 2, 1,
+
+		0, 0, 2, 1, 0, 2,
+		0, 1, 2, 1, 1, 2,
+		127
+	},
+#if 0
+#ifdef LIFE_NAMES
+	{"glider (p8 c/4)"},
+#endif
+	{
+		0, -2, -1,
+		1, -1, -1,
+		1, 0, -1,
+		0, 1, -1,
+
+		0, -2, 0,
+		-1, -1, 0, 0, -1, 0, 1, -1, 0,
+		-1, 0, 0, 0, 0, 0, 1, 0, 0,
+		0, 1, 0,
+		127
+	}
+#endif
+};
+
 /*-
  * S45/B5 life is probably the best
  * S567/B6 life has gliders like Conway's 2d S23/B3 life
@@ -46,7 +1192,7 @@ typedef struct {
  * so the others may be better
  */
 
-static char patterns_S45B5[][3 * NUMPTS + 1] =
+static char patterns_26S45B5[][3 * NUMPTS + 1] =
 {
 #if 0
 /* still life */
@@ -781,7 +1927,6 @@ static char patterns_S45B5[][3 * NUMPTS + 1] =
 
 		0, -1, -3, 0, -1, -2, 0, -1, 1, 0, -1, 2,
 		0, 0, -4, 0, 0, -1, 0, 0, 0, 0, 0, 3,
-		
 
 		1, -1, -3, 1, -1, -2, 1, -1, 1, 1, -1, 2,
 		1, 0, -4, 1, 0, 3,
@@ -909,7 +2054,7 @@ static char patterns_S45B5[][3 * NUMPTS + 1] =
 	}
 };
 
-static char patterns_S567B6[][3 * NUMPTS + 1] =
+static char patterns_26S567B6[][3 * NUMPTS + 1] =
 {
 #if 0
 #ifdef LIFE_NAMES
@@ -1713,7 +2858,7 @@ static char patterns_S567B6[][3 * NUMPTS + 1] =
  * Many names of S56/B5 & S67/B67 are made up by David Bagley.
  * They are listed in * order given by Carter Bays all p2 except "H"
  */
-static char patterns_S56B5[][3 * NUMPTS + 1] =
+static char patterns_26S56B5[][3 * NUMPTS + 1] =
 {
 #if 0
 #ifdef LIFE_NAMES
@@ -2781,7 +3926,7 @@ static char patterns_S56B5[][3 * NUMPTS + 1] =
 #endif
 };
 
-static char patterns_S678B5[][3 * NUMPTS + 1] =
+static char patterns_26S678B5[][3 * NUMPTS + 1] =
 {
 #if 0
 #ifdef LIFE_NAMES
@@ -2793,7 +3938,7 @@ static char patterns_S678B5[][3 * NUMPTS + 1] =
 		0, 1, -1, 0, 1, 0,
 		127
 	},
-#endif 
+#endif
 #ifdef LIFE_NAMES
 	{"arrow"},
 #endif
@@ -3072,6 +4217,19 @@ static char patterns_S678B5[][3 * NUMPTS + 1] =
 		0, 1, 0, 1, 1, 0,
 		127
 	},
+#ifdef LIFE_NAMES
+	{"small pump"},
+#endif
+	{
+		-1, 1, 0, 0, 1, 0,
+		-2, 0, 0, 0, 0, 0, 1, 0, 0,
+		-2, -1, 0, -1, -1, 0, 1, -1, 0,
+		-1, -2, 0, 0, -2, 0,
+
+		0, 0, 1,
+		-1, -1, 1,
+		127
+	},
 #ifdef LIFE_NAMES
 	{"spinning table"},
 #endif
@@ -3090,6 +4248,104 @@ static char patterns_S678B5[][3 * NUMPTS + 1] =
 		-1, 0, 1,
 		127
 	},
+#ifdef LIFE_NAMES
+	{"opposing rowers"},
+#endif
+	{
+		0, 2, -1,
+		-1, 1, -1, 0, 1, -1, 1, 1, -1,
+		-1, -1, -1, 0, -1, -1, 1, -1, -1,
+		0, -2, -1,
+
+		0, 2, 0,
+		-1, 1, 0, 1, 1, 0,
+		-1, -1, 0, 1, -1, 0,
+		0, -2, 0,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"suction cup"},
+#endif
+	{
+		-1, 1, -1, 0, 1, -1,
+		-2, 0, -1, -1, 0, -1, 0, 0, -1, 1, 0, -1,
+		-2, -1, -1, -1, -1, -1, 0, -1, -1, 1, -1, -1,
+		-1, -2, -1, 0, -2, -1,
+
+		-1, 0, 1, 0, 0, 1,
+		-1, -1, 1, 0, -1, 1,
+
+		-1, 0, 2, 0, 0, 2,
+		-1, -1, 2, 0, -1, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"compressor"},
+#endif
+	{
+		0, 2, -2,
+		0, 1, -2,
+		-2, 0, -2, -1, 0, -2, 1, 0, -2, 2, 0, -2,
+		0, -1, -2,
+		0, -2, -2,
+
+		-1, 1, -1, 0, 1, -1, 1, 1, -1,
+		-1, 0, -1, 1, 0, -1,
+		-1, -1, -1, 0, -1, -1, 1, -1, -1,
+
+		-1, 1, 1, 0, 1, 1, 1, 1, 1,
+		-1, 0, 1, 1, 0, 1,
+		-1, -1, 1, 0, -1, 1, 1, -1, 1,
+
+		0, 2, 2,
+		0, 1, 2,
+		-2, 0, 2, -1, 0, 2, 1, 0, 2, 2, 0, 2,
+		0, -1, 2,
+		0, -2, 2,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"pump"},
+#endif
+	{
+		-1, 2, 0, 0, 2, 0, 1, 2, 0,
+		-2, 1, 0, 0, 1, 0, 2, 1, 0,
+		-2, 0, 0, -1, 0, 0, 1, 0, 0, 2, 0, 0,
+		-2, -1, 0, 0, -1, 0, 2, -1, 0,
+		-1, -2, 0, 0, -2, 0, 1, -2, 0,
+
+		0, 1, 1,
+		-1, 0, 1, 1, 0, 1,
+		0, -1, 1,
+		127
+	},
+#ifdef LIFE_NAMES
+	{"big corner (p3)"},
+#endif
+	{
+		1, -1, -2, 2, -1, -2,
+		1, -2, -2,
+
+		1, 0, -1, 2, 0, -1,
+		0, -1, -1,
+		0, -2, -1,
+
+		1, 1, 0, 2, 1, 0,
+		-1, -1, 0, 1, -1, 0,
+		-1, -2, 0,
+
+		1, 2, 1, 2, 2, 1,
+		0, 1, 1,
+		-1, 0, 1, 1, 0, 1,
+		-2, -1, 1, 0, -1, 1,
+		-2, -2, 1,
+
+		1, 2, 2,
+		0, 1, 2,
+		-1, 0, 2,
+		-2, -1, 2,
+		127
+	},
 #ifdef LIFE_NAMES
 	{"H (p3)"},
 #endif
@@ -3167,6 +4423,19 @@ static char patterns_S678B5[][3 * NUMPTS + 1] =
 		0, 0, 1,
 		127
 	},
+#ifdef LIFE_NAMES
+	{"mirror image (p6)"},
+#endif
+	{
+		0, -1, -1, 1, -1, -1,
+		0, 1, -1, 1, 1, -1,
+
+		-1, -2, 0, 0, -2, 0, 1, -2, 0,
+		-1, -1, 0, 0, -1, 0,
+		-1, 1, 0, 0, 1, 0,
+		-1, 2, 0, 0, 2, 0, 1, 2, 0,
+		127
+	},
 #if 0
 #ifdef LIFE_NAMES
 	{"glider 1 (14 cell diag, p2)"},
@@ -3218,7 +4487,7 @@ static char patterns_S678B5[][3 * NUMPTS + 1] =
 	}
 };
 
-static char patterns_S67B67[][3 * NUMPTS + 1] =
+static char patterns_26S67B67[][3 * NUMPTS + 1] =
 {
 #ifdef LIFE_NAMES
 	{"S"},
@@ -3754,7 +5023,7 @@ static char patterns_S67B67[][3 * NUMPTS + 1] =
 		127
 	},
 #ifdef LIFE_NAMES
-	{"solitare"},
+	{"solitaire"},
 #endif
 	{
 		-1, -3, -1, 0, -3, -1, 1, -3, -1,
@@ -3812,7 +5081,7 @@ static char patterns_S67B67[][3 * NUMPTS + 1] =
 		127
 	},
 #ifdef LIFE_NAMES
-	{"large solitare"},
+	{"large solitaire"},
 #endif
 	{
 		-1, -5, -1, 0, -5, -1,
@@ -4064,28 +5333,82 @@ static char patterns_S67B67[][3 * NUMPTS + 1] =
 #define DIV 1
 #endif
 
-static int  patterns_rules[] =
+static int  patterns_12rules[] =
 {
-	(sizeof patterns_S45B5 / sizeof patterns_S45B5[0]) / DIV,
-	(sizeof patterns_S567B6 / sizeof patterns_S567B6[0]) / DIV,
-	(sizeof patterns_S56B5 / sizeof patterns_S56B5[0]) / DIV,
-	(sizeof patterns_S678B5 / sizeof patterns_S678B5[0]) / DIV,
-	(sizeof patterns_S67B67 / sizeof patterns_S67B67[0]) / DIV
+	(sizeof patterns_12S3B3 / sizeof patterns_12S3B3[0]) / DIV,
+	(sizeof patterns_12S456B3 / sizeof patterns_12S456B3[0]) / DIV,
 };
 
-static paramstruct param_rules[] =
+static int  patterns_18rules[] =
 {
-	{0x30, 0x20},
-	{0xE0, 0x40},
-	{0x60, 0x20},
-	{0x1C0, 0x20},
-	{0xC0, 0xC0}
+	(sizeof patterns_18S45B4 / sizeof patterns_18S45B4[0]) / DIV,
 };
 
-#define LIFE_S45B5 0
-#define LIFE_S567B6 1
-#define LIFE_S56B5 2
-#define LIFE_S678B5 3
-#define LIFE_GLIDERS 4	/* GLIDER rules are first in param_rules */
-#define LIFE_S67B67 4
-#define LIFE_RULES (sizeof patterns_rules / sizeof patterns_rules[0])
+static int  patterns_20rules[] =
+{
+	(sizeof patterns_20S45B4 / sizeof patterns_20S45B4[0]) / DIV,
+};
+
+static int  patterns_26rules[] =
+{
+	(sizeof patterns_26S45B5 / sizeof patterns_26S45B5[0]) / DIV,
+	(sizeof patterns_26S567B6 / sizeof patterns_26S567B6[0]) / DIV,
+	(sizeof patterns_26S56B5 / sizeof patterns_26S56B5[0]) / DIV,
+	(sizeof patterns_26S678B5 / sizeof patterns_26S678B5[0]) / DIV,
+	(sizeof patterns_26S67B67 / sizeof patterns_26S67B67[0]) / DIV
+};
+
+static paramstruct param_6rules[] =
+{
+};
+
+static paramstruct param_8rules[] =
+{
+};
+
+static paramstruct param_12rules[] =
+{
+	{0x8, 0x8}, /* LIFE_12S3B3 */
+	{0x70, 0x8} /* LIFE_12S456B3 */
+};
+
+static paramstruct param_14rules[] =
+{
+};
+
+static paramstruct param_18rules[] =
+{
+	{0x30, 0x10} /* LIFE_18S45B4 */
+};
+
+static paramstruct param_20rules[] =
+{
+	{0x30, 0x10} /* LIFE_20S45B4 */
+};
+
+static paramstruct param_26rules[] =
+{
+	{0x30, 0x20}, /* LIFE_26S45B5 */
+	{0xE0, 0x40}, /* LIFE_26S567B6 */
+	{0x60, 0x20}, /* LIFE_26S56B5 */
+	{0x1C0, 0x20}, /* LIFE_26S678B5 */
+	{0xC0, 0xC0} /* LIFE_26S67B67 */
+};
+
+#define LIFE_12S3B3 0
+#define LIFE_12S456B3 1
+#define LIFE_12GLIDERS 2
+#define LIFE_18S45B4 0
+#define LIFE_18GLIDERS 1
+#define LIFE_20S45B4 0
+#define LIFE_20GLIDERS 1
+#define LIFE_26S45B5 0
+#define LIFE_26S567B6 1
+#define LIFE_26S56B5 2
+#define LIFE_26S678B5 3
+#define LIFE_26GLIDERS 4	/* GLIDER rules are first in param_26rules */
+#define LIFE_26S67B67 4
+#define LIFE_12RULES (sizeof patterns_12rules / sizeof patterns_12rules[0])
+#define LIFE_18RULES (sizeof patterns_18rules / sizeof patterns_18rules[0])
+#define LIFE_20RULES (sizeof patterns_20rules / sizeof patterns_20rules[0])
+#define LIFE_26RULES (sizeof patterns_26rules / sizeof patterns_26rules[0])
