@@ -62,17 +62,17 @@ static XrmOptionDescRec opts[] =
 	{(char *) "-duration", (char *) ".random.duration", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-modelist", (char *) ".random.modelist", XrmoptionSepArg, (caddr_t) NULL},
 	{(char *) "-sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "on"},
-      {(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
+	{(char *) "+sequential", (char *) ".random.sequential", XrmoptionNoArg, (caddr_t) "off"},
 	{(char *) "-fullrandom", (char *) ".random.fullrandom", XrmoptionNoArg, (caddr_t) "on"},
 	{(char *) "+fullrandom", (char *) ".random.fullrandom", XrmoptionNoArg, (caddr_t) "off"}
 };
 
 static argtype vars[] =
 {
-	{(caddr_t *) & duration, (char *) "duration", (char *) "Duration", (char *) DEF_DURATION, t_Int},
-    {(caddr_t *) & modelist, (char *) "modelist", (char *) "Modelist", (char *) DEF_MODELIST, t_String},
-	{(caddr_t *) & sequential, (char *) "sequential", (char *) "Sequential", (char *) DEF_SEQUENTIAL, t_Bool},
-{(caddr_t *) & fullrandom, (char *) "fullrandom", (char *) "FullRandom", (char *) DEF_FULLRANDOM, t_Bool}
+	{(void *) & duration, (char *) "duration", (char *) "Duration", (char *) DEF_DURATION, t_Int},
+	{(void *) & modelist, (char *) "modelist", (char *) "Modelist", (char *) DEF_MODELIST, t_String},
+	{(void *) & sequential, (char *) "sequential", (char *) "Sequential", (char *) DEF_SEQUENTIAL, t_Bool},
+	{(void *) & fullrandom, (char *) "fullrandom", (char *) "FullRandom", (char *) DEF_FULLRANDOM, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -142,6 +142,9 @@ static char gl_modes[][MAXMODECHARS] =
 #ifdef MODE_atunnels
 	"atunnels",
 #endif
+#ifdef MODE_biof
+	"biof",
+#endif
 #ifdef MODE_bubble3d
 	"bubble3d",
 #endif
@@ -265,6 +268,9 @@ static char write_modes[][MAXMODECHARS] =
 #ifdef MODE_tik_tak
 	"tik_tak",
 #endif
+#ifdef MODE_toneclock
+	"toneclock",
+#endif
 #ifdef MODE_tube
 	"tube"
 #endif
@@ -275,6 +281,9 @@ static char write_modes[][MAXMODECHARS] =
 
 static char nice_modes[][MAXMODECHARS] =
 {
+#ifdef MODE_apollonian
+	"apollonian",
+#endif
 #ifdef MODE_blot
 	"blot",
 #endif
@@ -287,21 +296,24 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_clock
 	"clock",
 #endif
-#ifdef MODE_crystal
-	"crystal",
-#endif
 #ifdef MODE_daisy
 	"daisy",
 #endif
 #ifdef MODE_dclock
 	"dclock",
 #endif
-#ifdef MODE_demon
-	"demon",
+#ifdef MODE_decay
+	"decay",
 #endif
 #ifdef MODE_deco
 	"deco",
 #endif
+#ifdef MODE_demon
+	"demon",
+#endif
+#ifdef MODE_dilemma
+	"dilemma",
+#endif
 #ifdef MODE_dragon
 	"dragon",
 #endif
@@ -311,17 +323,17 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_fadeplot
 	"fadeplot",
 #endif
-#ifdef MODE_flag
-	"flag",
-#endif
 #ifdef MODE_flame
 	"flame",
 #endif
+#ifdef MODE_forest
+	"forest",
+#endif
 #ifdef MODE_grav
 	"grav",
 #endif
-#ifdef MODE_helix
-	"helix",
+#ifdef MODE_hop
+	"hop",
 #endif
 #ifdef MODE_hyper
 	"hyper",
@@ -335,9 +347,6 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_kaleid
 	"kaleid",
 #endif
-#ifdef MODE_laser
-  "laser",
-#endif
 #ifdef MODE_life
   "life",
 #endif
@@ -362,18 +371,21 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_marquee
 	"marquee",
 #endif
+#ifdef MODE_munch
+	"munch",
+#endif
 #ifdef MODE_nose
 	"nose",
 #endif
+#ifdef MODE_pacman
+	"pacman",
+#endif
 #ifdef MODE_penrose
 	"penrose",
 #endif
 #ifdef MODE_petal
 	"petal",
 #endif
-#ifdef MODE_petri
-	"petri",
-#endif
 #ifdef MODE_puzzle
 	"puzzle",
 #endif
@@ -386,17 +398,17 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_roll
 	"roll",
 #endif
-#ifdef MODE_rotor
-	"rotor",
+#ifdef MODE_solitaire
+	"solitaire",
 #endif
-#ifdef MODE_shape
-	"shape",
+#ifdef MODE_space
+	"space",
 #endif
-#ifdef MODE_sierpinski
-	"sierpinski",
+#ifdef MODE_sphere
+	"sphere",
 #endif
-#ifdef MODE_solitare
-	"solitare",
+#ifdef MODE_spiral
+	"spiral",
 #endif
 #ifdef MODE_spline
 	"spline",
@@ -407,6 +419,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_swarm
 	"swarm",
 #endif
+#ifdef MODE_tetris
+	"tetris",
+#endif
 #ifdef MODE_triangle
 	"triangle",
 #endif
@@ -419,8 +434,8 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_vines
 	"vines",
 #endif
-#ifdef MODE_voters
-	"voters",
+#ifdef MODE_wator
+	"wator",
 #endif
 #ifdef MODE_wire
 	"wire",
@@ -431,6 +446,9 @@ static char nice_modes[][MAXMODECHARS] =
 #ifdef MODE_worm
 	"worm",
 #endif
+#ifdef MODE_xcl
+	"xcl",
+#endif
 #ifdef MODE_xjack
 	"xjack"
 #endif
@@ -468,8 +486,8 @@ static char mouse_modes[][MAXMODECHARS] =
 #ifdef MODE_pacman
 	"pacman",
 #endif
-#ifdef MODE_solitare
-	"solitare",
+#ifdef MODE_solitaire
+	"solitaire",
 #endif
 #ifdef MODE_tetris
 	"tetris",
@@ -664,7 +682,10 @@ static char geometry_modes[][MAXMODECHARS] =
 	"spline",
 #endif
 #ifdef MODE_tik_tak
-	"tik_tak"
+	"tik_tak",
+#endif
+#ifdef MODE_toneclock
+	"toneclock"
 #endif
 };
 
@@ -921,6 +942,10 @@ parsemodelist(ModeInfo * mi)
 	}
 	return True;
 }
+#ifdef WIN32
+extern int showtext;/* from xlock.c */
+extern char* xlock95_get_modelist(void);/* from xlock95.c */
+#endif
 
 static void
 setMode(ModeInfo * mi, int newmode)
@@ -940,14 +965,30 @@ setMode(ModeInfo * mi, int newmode)
 	saturation = MI_SATURATION(mi) = LockProcs[currentmode].def_saturation;
 	bitmap = MI_BITMAP(mi) = LockProcs[currentmode].def_bitmap;
 
+#ifndef WIN32
 	for (i = startscreen; i < MI_NUM_SCREENS(mi); i++) {
 
 		XChangeGC(MI_DISPLAY(mi), MI_GC(mi), GC_SAVE_VALUES,
 			  &(rp->gcvs));		/* Not sure if this is right for multiscreens */
 		randoms[i].fix = True;
 	}
+#endif
 	if (MI_IS_VERBOSE(mi))
 		(void) fprintf(stderr, "mode %d: %s\n", currentmode, LockProcs[currentmode].cmdline_arg);
+#ifdef WIN32
+	{
+	  ModeSpecOpt *ms = LockProcs[currentmode].msopt;
+	  /*MI_COLORMAP_SIZE(mi) = ncolors = mi->screeninfo->npixels = colorcount;*/
+	  XFreeGC(MI_DISPLAY(mi), MI_GC(mi));
+	  MI_GC(mi) = GCCreate();
+	  xlockmore_set_mode_options(ms);
+
+	  /* Needed because WIN32 sections of xlock.c use these as
+		 globals */
+	  /*randommode = currentmode;
+	  showtext=0;*/
+	}
+#endif
 }
 
 void
@@ -962,7 +1003,10 @@ init_random(ModeInfo * mi)
 			return;
 	}
 	rp = &randoms[MI_SCREEN(mi)];
-
+#ifdef WIN32
+	/* Fetch current modelist from registry */
+	modelist = xlock95_get_modelist();
+#endif
 	MI_SET_FLAG_STATE(mi, WI_FLAG_FULLRANDOM, fullrandom);
 	if (currentmode < 0) {
 		if (!parsemodelist(mi))
