@@ -65,6 +65,7 @@ static const char sccsid[] = "@(#)tetris.c	5.01 2000/12/19 xlockmore";
  */
 
 #ifdef STANDALONE
+#define MODE_tetris
 #define PROGCLASS "Tetris"
 #define HACK_INIT init_tetris
 #define HACK_DRAW draw_tetris
@@ -117,13 +118,13 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-  {(caddr_t *) & bonus, (char *) "bonus", (char *) "Bonus", (char *) DEF_BONUS, t_Bool},
-  {(caddr_t *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool},
-  {(caddr_t *) & plain, (char *) "plain", (char *) "Plain", (char *) DEF_PLAIN, t_Bool},
+  {(void *) & bonus, (char *) "bonus", (char *) "Bonus", (char *) DEF_BONUS, t_Bool},
+  {(void *) & cycle_p, (char *) "cycle", (char *) "Cycle", (char *) DEF_CYCLE, t_Bool},
+  {(void *) & plain, (char *) "plain", (char *) "Plain", (char *) DEF_PLAIN, t_Bool},
 #ifndef DISABLE_INTERACTIVE
-  {(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
+  {(void *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool},
 #endif
-  {(caddr_t *) & well, (char *) "well", (char *) "Well", (char *) DEF_WELL, t_Bool}
+  {(void *) & well, (char *) "well", (char *) "Well", (char *) DEF_WELL, t_Bool}
 };
 static OptionStruct desc[] =
 {
@@ -150,9 +151,9 @@ ModStruct   tetris_description =
 
 #include "bitmaps/gray1.xbm"
 
-#define MINGRIDSIZE 10 
+#define MINGRIDSIZE 10
 #define MAXPIXELSIZE 12
-#define MINSIZE 6 
+#define MINSIZE 6
 #define MAX_SIDES 4
 
 #define NUM_FLASHES 16
@@ -285,7 +286,7 @@ typedef struct {
 #define G ((tp->ys/45)+1)         /* 1/2 of gap between pentominoes. */
 #define T ((tp->ys<=12)?1:(G*2))  /* Thickness of walls of pentominoes. */
 #define R ((tp->ys<=12)?1:(G*6))  /* Amount of rounding. */
-#define RT ((tp->ys<=12)?1:(G*3)) /* Thickness of wall of rounded parts. 
+#define RT ((tp->ys<=12)?1:(G*3)) /* Thickness of wall of rounded parts.
                                   Here 3 is an approximation to 2 sqrt(2).  */
 #define RR 0   /* Roof ridge thickness */
 
@@ -472,7 +473,7 @@ image_needed(int n) {
   return 0;
 }
 
-static void 
+static void
 leadingEmptyWidth(Polyominoes * polyo)
 {
   int i, j;
@@ -507,7 +508,7 @@ leadingEmptyHeight(Polyominoes * polyo)
 static Bool
 readPolyominoes(void)
 {
-  int   size, n, index = 0, sum = 0;
+  int   size, n, polyindex = 0, sum = 0;
   int   counter, start_counter;
   int   polyomino, kinds, i, j, bonustype;
 
@@ -515,12 +516,12 @@ readPolyominoes(void)
     counter = 0, start_counter = 0;
     polytris[bonustype].mode.number = start_ominoes[bonustype];
     for (kinds = 0; kinds < area_kinds[bonustype]; kinds++) {
-      size = ominos[index++];
+      size = ominos[polyindex++];
       if (size > omino_squares[bonustype]) {
         (void) printf("tetris corruption: size %d\n", size);
         return False;
       }
-      n = ominos[index++];
+      n = ominos[polyindex++];
       if (sum > max_ominoes[bonustype]) {
         (void) printf("tetris corruption: n %d\n", n);
         return False;
@@ -533,18 +534,18 @@ readPolyominoes(void)
             bonustype, polyomino, counter);
           return False;
         }
-        if (polyomino != ominos[index]) {
-          (void) printf("tetris corruption: polyomino %d, ominos[index] %d\n",
-            polyomino, ominos[index]);
+        if (polyomino != ominos[polyindex]) {
+          (void) printf("tetris corruption: polyomino %d, ominos[polyindex] %d\n",
+            polyomino, ominos[polyindex]);
           return False;
         }
-        index++;  /* This is only there to "read" it */
+        polyindex++;  /* This is only there to "read" it */
         polytris[bonustype].polyomino[sum].rotation =
-          ominos[index++] + counter;
+          ominos[polyindex++] + counter;
         polytris[bonustype].polyomino[sum].reflection =
-          ominos[index++] + counter; /* not used */
+          ominos[polyindex++] + counter; /* not used */
 
-        if (ominos[index++]) {
+        if (ominos[polyindex++]) {
           if (start_counter < start_ominoes[bonustype]) {
             polytris[bonustype].mode.start[start_counter++] = sum;
           } else {
@@ -562,7 +563,7 @@ readPolyominoes(void)
         for (j = 0; j < size; j++) {
           for (i = 0; i < size; i++) {
             polytris[bonustype].polyomino[sum].shape[j * size + i] =
-        ominos[index++];
+        ominos[polyindex++];
           }
         }
         leadingEmptyWidth(&(polytris[bonustype].polyomino[sum]));
@@ -606,7 +607,7 @@ writePolyominoes(trisstruct * tp)
 #endif
 
 static void
-setColour(ModeInfo * mi, int cid /* , int exor */) 
+setColour(ModeInfo * mi, int cid /* , int exor */)
 {
   Display    *display = MI_DISPLAY(mi);
   trisstruct *tp = &triss[MI_SCREEN(mi)];
@@ -1054,8 +1055,6 @@ drawPolyomino(ModeInfo * mi)
         if (polytris[(int) tp->bonusNow].polyomino
                     [tp->curPolyomino.polyomino_number].shape
                     [j * tp->curPolyomino.size + i]) {
-          int xi, yj;
-
           xi = (tp->curPolyomino.xpos + i) % WELL_PERIMETER;
           yj = tp->curPolyomino.ypos + j;
           if (yj >= WELL_DEPTH) {
@@ -1454,12 +1453,12 @@ wallChange(ModeInfo *mi, thing_t oldthing, thing_t newthing)
 
   for (i = 0; i < oldthing.size; i++)
     for (j = 0; j < oldthing.size; j++)
-  if (polytris[(int) tp->bonusNow].polyomino[oldthing.polyomino_number].shape[j * tp->curPolyomino.size + i]) {
-    if (w == -1)
-      w = ((x + i) % WELL_PERIMETER) / WELL_WIDTH;
-    else if (w != ((x + i) % WELL_PERIMETER) / WELL_WIDTH)
-      return True;
-  }
+      if (polytris[(int) tp->bonusNow].polyomino[oldthing.polyomino_number].shape[j * tp->curPolyomino.size + i]) {
+        if (w == -1)
+          w = ((x + i) % WELL_PERIMETER) / WELL_WIDTH;
+        else if (w != ((x + i) % WELL_PERIMETER) / WELL_WIDTH)
+          return True;
+      }
   for (i = 0; i < newthing.size; i++)
     for (j = 0; j < newthing.size; j++)
       if (polytris[(int) tp->bonusNow].polyomino
@@ -1553,7 +1552,7 @@ fillLines(ModeInfo *mi)
   if (tp->well) {
     for (j = 0; j < WELL_DEPTH + WELL_WIDTH; j++)
       for (i = 0; i < WELL_PERIMETER; i++) {
-         drawBox(mi, BITMAPS - 1, 
+         drawBox(mi, BITMAPS - 1,
            LRAND() % polytris[(int) tp->bonusNow].mode.number,
                  i, j);
          XFlush(display);
@@ -1616,7 +1615,7 @@ free_tetris(Display *display, trisstruct *tp)
     if (tp->colors != NULL) {
       if (tp->ncolors && !tp->no_colors)
         free_colors(display, tp->cmap, tp->colors, tp->ncolors);
-      (void) free((void *) tp->colors);
+      free(tp->colors);
       tp->colors = (XColor *) NULL;
     }
     if (tp->cmap != None) {
@@ -1633,7 +1632,7 @@ free_tetris(Display *display, trisstruct *tp)
     tp->graypix = None;
   }
   if (tp->field != NULL) {
-     (void) free((void *) tp->field);
+     free(tp->field);
      tp->field = (fieldstruct *) NULL;
   }
   free_images(tp);
@@ -1845,7 +1844,7 @@ checkLines(ModeInfo *mi)
     }
 
     if (lSet)
-      (void) free((void *) lSet);
+      free(lSet);
     return nset;
   }
 }
@@ -1869,7 +1868,7 @@ create_an_image(ModeInfo *mi, trisstruct *tp, int n)
 
   for (y=0;y<tp->ys;y++) for (x=0;x<tp->ys;x++) {
      if (!tp->use3D) {
-#ifdef SMALL_BELLYBUTTON 
+#ifdef SMALL_BELLYBUTTON
         if (x >= tp->ys / 2 && x <= tp->ys / 2 + 1 &&
             y >= tp->ys / 2 && y <= tp->ys / 2 + 1)
           NOTHALFBIT(x,y)
@@ -1895,29 +1894,37 @@ create_an_image(ModeInfo *mi, trisstruct *tp, int n)
   }
 
   if (IS_LEFT(n))
-    for (y=0;y<tp->ys;y++) for (x=G;x<G+T;x++)
-      SETBIT(x,y)
+    for (y=0;y<tp->ys;y++)
+      for (x=G;x<G+T;x++)
+        SETBIT(x,y)
   if (IS_RIGHT(n))
-    for (y=0;y<tp->ys;y++) for (x=G;x<G+T;x++)
-      SETBIT(tp->ys-1-x,y)
+    for (y=0;y<tp->ys;y++)
+      for (x=G;x<G+T;x++)
+        SETBIT(tp->ys-1-x,y)
   if (IS_UP(n))
-    for (x=0;x<tp->ys;x++) for (y=G;y<G+T;y++)
-      SETBIT(x,y)
+    for (x=0;x<tp->ys;x++)
+      for (y=G;y<G+T;y++)
+        SETBIT(x,y)
   if (IS_DOWN(n))
-    for (x=0;x<tp->ys;x++) for (y=G;y<G+T;y++)
-      SETBIT(x,tp->ys-1-y)
+    for (x=0;x<tp->ys;x++)
+      for (y=G;y<G+T;y++)
+        SETBIT(x,tp->ys-1-y)
   if (IS_LEFT(n))
-    for (y=0;y<tp->ys;y++) for (x=0;x<G;x++)
-      RESBIT(x,y)
+    for (y=0;y<tp->ys;y++)
+      for (x=0;x<G;x++)
+        RESBIT(x,y)
   if (IS_RIGHT(n))
-    for (y=0;y<tp->ys;y++) for (x=0;x<G;x++)
-      RESBIT(tp->ys-1-x,y)
+    for (y=0;y<tp->ys;y++)
+      for (x=0;x<G;x++)
+        RESBIT(tp->ys-1-x,y)
   if (IS_UP(n))
-    for (x=0;x<tp->ys;x++) for (y=0;y<G;y++)
-      RESBIT(x,y)
+    for (x=0;x<tp->ys;x++)
+      for (y=0;y<G;y++)
+        RESBIT(x,y)
   if (IS_DOWN(n))
-    for (x=0;x<tp->ys;x++) for (y=0;y<G;y++)
-      RESBIT(x,tp->ys-1-y)
+    for (x=0;x<tp->ys;x++)
+      for (y=0;y<G;y++)
+        RESBIT(x,tp->ys-1-y)
 
   if (IS_LEFT(n) && IS_UP(n))
     for (x=G;x<=G+R;x++)
@@ -1953,73 +1960,93 @@ create_an_image(ModeInfo *mi, trisstruct *tp, int n)
       }
 
   if (!IS_LEFT(n) && !IS_UP(n) && IS_LEFT_UP(n)) {
-    for (x=0;x<G;x++) for(y=0;y<G;y++)
-      RESBIT(x,y)
-    for (x=G;x<G+T;x++) for(y=0;y<G;y++)
-      SETBIT(x,y)
-    for (x=0;x<G+T;x++) for(y=G;y<G+T;y++)
-      SETBIT(x,y)
+    for (x=0;x<G;x++)
+      for(y=0;y<G;y++)
+        RESBIT(x,y)
+    for (x=G;x<G+T;x++)
+      for(y=0;y<G;y++)
+        SETBIT(x,y)
+    for (x=0;x<G+T;x++)
+      for(y=G;y<G+T;y++)
+        SETBIT(x,y)
   }
   if (!IS_LEFT(n) && !IS_DOWN(n) && IS_LEFT_DOWN(n)) {
-    for (x=0;x<G;x++) for(y=0;y<G;y++)
-      RESBIT(x,tp->ys-1-y)
-    for (x=G;x<G+T;x++) for(y=0;y<G;y++)
-      SETBIT(x,tp->ys-1-y)
-    for (x=0;x<G+T;x++) for(y=G;y<G+T;y++)
-      SETBIT(x,tp->ys-1-y)
+    for (x=0;x<G;x++)
+      for(y=0;y<G;y++)
+        RESBIT(x,tp->ys-1-y)
+    for (x=G;x<G+T;x++)
+      for(y=0;y<G;y++)
+        SETBIT(x,tp->ys-1-y)
+    for (x=0;x<G+T;x++)
+      for(y=G;y<G+T;y++)
+        SETBIT(x,tp->ys-1-y)
   }
   if (!IS_RIGHT(n) && !IS_UP(n) && IS_RIGHT_UP(n)) {
-    for (x=0;x<G;x++) for(y=0;y<G;y++)
-      RESBIT(tp->ys-1-x,y)
-    for (x=G;x<G+T;x++) for(y=0;y<G;y++)
-      SETBIT(tp->ys-1-x,y)
-    for (x=0;x<G+T;x++) for(y=G;y<G+T;y++)
-      SETBIT(tp->ys-1-x,y)
+    for (x=0;x<G;x++)
+      for(y=0;y<G;y++)
+        RESBIT(tp->ys-1-x,y)
+    for (x=G;x<G+T;x++)
+      for(y=0;y<G;y++)
+        SETBIT(tp->ys-1-x,y)
+    for (x=0;x<G+T;x++)
+      for(y=G;y<G+T;y++)
+        SETBIT(tp->ys-1-x,y)
   }
   if (!IS_RIGHT(n) && !IS_DOWN(n) && IS_RIGHT_DOWN(n)) {
-    for (x=0;x<G;x++) for(y=0;y<G;y++)
-      RESBIT(tp->ys-1-x,tp->ys-1-y)
-    for (x=G;x<G+T;x++) for(y=0;y<G;y++)
-      SETBIT(tp->ys-1-x,tp->ys-1-y)
-    for (x=0;x<G+T;x++) for(y=G;y<G+T;y++)
-      SETBIT(tp->ys-1-x,tp->ys-1-y)
+    for (x=0;x<G;x++)
+      for(y=0;y<G;y++)
+        RESBIT(tp->ys-1-x,tp->ys-1-y)
+    for (x=G;x<G+T;x++)
+      for(y=0;y<G;y++)
+        SETBIT(tp->ys-1-x,tp->ys-1-y)
+    for (x=0;x<G+T;x++)
+      for(y=G;y<G+T;y++)
+        SETBIT(tp->ys-1-x,tp->ys-1-y)
   }
-#ifdef LARGE_BELLYBUTTON 
+#ifdef LARGE_BELLYBUTTON
   if (!tp->use3D) {
     if (!IS_LEFT(n) && !IS_UP(n) && !IS_LEFT_UP(n))
-      for (x=0;x<G+T;x++) for(y=0;y<G+T;y++)
-        SETBIT(x,y)
+      for (x=0;x<G+T;x++)
+        for(y=0;y<G+T;y++)
+          SETBIT(x,y)
     if (!IS_LEFT(n) && !IS_DOWN(n) && !IS_LEFT_DOWN(n))
-      for (x=0;x<G+T;x++) for(y=tp->ys-G-T;y<tp->ys;y++)
-        SETBIT(x,y)
+      for (x=0;x<G+T;x++)
+        for(y=tp->ys-G-T;y<tp->ys;y++)
+          SETBIT(x,y)
     if (!IS_RIGHT(n) && !IS_UP(n) && !IS_RIGHT_UP(n))
-      for (x=tp->ys-G-T;x<tp->ys;x++) for(y=0;y<G+T;y++)
-        SETBIT(x,y)
+      for (x=tp->ys-G-T;x<tp->ys;x++)
+        for(y=0;y<G+T;y++)
+          SETBIT(x,y)
     if (!IS_RIGHT(n) && !IS_DOWN(n) && !IS_RIGHT_DOWN(n))
-      for (x=tp->ys-G-T;x<tp->ys;x++) for(y=tp->ys-G-T;y<tp->ys;y++)
-        SETBIT(x,y)
+      for (x=tp->ys-G-T;x<tp->ys;x++)
+        for(y=tp->ys-G-T;y<tp->ys;y++)
+          SETBIT(x,y)
   } else
 #else
   if (tp->use3D)
 #endif
   {
     if (!IS_LEFT(n) && !IS_UP(n) && !IS_LEFT_UP(n))
-      for (x=0;x<tp->ys/2-RR;x++) for(y=0;y<tp->ys/2-RR;y++)
-        THREEQUARTERSBIT(x,y)
+      for (x=0;x<tp->ys/2-RR;x++)
+        for(y=0;y<tp->ys/2-RR;y++)
+          THREEQUARTERSBIT(x,y)
     if (!IS_LEFT(n) && !IS_DOWN(n) && !IS_LEFT_DOWN(n))
-      for (x=0;x<tp->ys/2-RR;x++) for(y=tp->ys/2+RR;y<tp->ys;y++)
-        THREEQUARTERSBIT(x,y)
+      for (x=0;x<tp->ys/2-RR;x++)
+        for(y=tp->ys/2+RR;y<tp->ys;y++)
+          THREEQUARTERSBIT(x,y)
     if (!IS_RIGHT(n) && !IS_UP(n) && !IS_RIGHT_UP(n))
-      for (x=tp->ys/2+RR;x<tp->ys;x++) for(y=0;y<tp->ys/2-RR;y++)
-        THREEQUARTERSBIT(x,y)
+      for (x=tp->ys/2+RR;x<tp->ys;x++)
+        for(y=0;y<tp->ys/2-RR;y++)
+          THREEQUARTERSBIT(x,y)
     if (!IS_RIGHT(n) && !IS_DOWN(n) && !IS_RIGHT_DOWN(n))
-      for (x=tp->ys/2+RR;x<tp->ys;x++) for(y=tp->ys/2+RR;y<tp->ys;y++)
-        THREEQUARTERSBIT(x,y)
+      for (x=tp->ys/2+RR;x<tp->ys;x++)
+        for(y=tp->ys/2+RR;y<tp->ys;y++)
+          THREEQUARTERSBIT(x,y)
   }
 
   if ((tp->images[n] = XCreateImage(MI_DISPLAY(mi), MI_VISUAL(mi),
            1, XYBitmap, 0, (char *) data, tp->xs, tp->ys, 8, 0)) == None) {
-     (void) free((void *) data);
+     free(data);
      return False;
   }
   tp->images[n]->byte_order = MSBFirst;
@@ -2091,7 +2118,7 @@ refresh_tetris(ModeInfo * mi)
     for (col = 0; col < tp->ncols; col++)
       for (row = 0; row < tp->nrows; row++) {
         pos = row * tp->ncols + col;
-#if DEBUG 
+#ifdef DEBUG
         (void) printf("pmid %d, cid %d, %d %d\n",
           tp->field[pos].pmid, tp->field[pos].cid, col, row);
 #endif
@@ -2111,19 +2138,19 @@ release_tetris(ModeInfo * mi) {
 
     for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
        free_tetris(MI_DISPLAY(mi), &triss[screen]);
-    (void) free((void *) triss);
+    free(triss);
     triss = (trisstruct *) NULL;
     for (bonustype = 0; bonustype < 2; bonustype++) {
       if (polytris[bonustype].polyomino != NULL) {
         for (number = 0; number < max_ominoes[bonustype]; number++) {
           if (polytris[bonustype].polyomino[number].shape != NULL)
-            (void) free((void *) polytris[bonustype].polyomino[number].shape);
+            free(polytris[bonustype].polyomino[number].shape);
         }
-        (void) free((void *) polytris[bonustype].polyomino);
+        free(polytris[bonustype].polyomino);
         polytris[bonustype].polyomino = (Polyominoes *) NULL;
       }
       if (polytris[bonustype].mode.start != NULL) {
-        (void) free((void *) polytris[bonustype].mode.start);
+        free(polytris[bonustype].mode.start);
         polytris[bonustype].mode.start = (int *) NULL;
       }
     }
@@ -2303,12 +2330,12 @@ init_tetris(ModeInfo * mi) {
       tp->frozen_wall[i] = 0;
     }
   } else {
-    tp->ncols = MAX(tp->width / tp->xs, 2);
-    tp->nrows = MAX(tp->height / tp->ys, 2);
+    tp->ncols = MAX(tp->width / tp->xs, 5);
+    tp->nrows = MAX(tp->height / tp->ys, 5);
     tp->xb = (tp->width - tp->xs * tp->ncols) / 2;
     tp->yb = (tp->height - tp->ys * tp->nrows) / 2;
     if (tp->field != NULL)
-      (void) free((void *) tp->field);
+      free(tp->field);
     if ((tp->field = (fieldstruct *) malloc(tp->ncols * tp->nrows *
         sizeof (fieldstruct))) == NULL) {
       free_tetris(display, tp);
@@ -2329,7 +2356,7 @@ init_tetris(ModeInfo * mi) {
     if (tp->colors != NULL) {
       if (tp->ncolors && !tp->no_colors)
         free_colors(display, tp->cmap, tp->colors, tp->ncolors);
-      (void) free((void *) tp->colors);
+      free(tp->colors);
       tp->colors = (XColor *) NULL;
     }
     tp->ncolors = MI_NCOLORS(mi);
