@@ -25,11 +25,11 @@
 				1000000 * ( tp.tv_sec - t1_prev ));
 			interval = actual_delay * granularity - interval;
 			if (interval > 0)
-				usleep(interval);
+				(void) usleep(interval);
 			GETTIMEOFDAY(&tp);
 			t_prev = (int) (tp.tv_usec);
 			t1_prev = (int) (tp.tv_sec);
 		}
 #else
-			usleep( actual_delay * granularity );
+			(void) usleep( actual_delay * granularity );
 #endif
